@@ -11,12 +11,13 @@
 (function() {
 	var TEMPLATE =
 		'<div class="activity-section">' +
-		'{{#if loading}}' +
-		'<div class="loading" style="height: 50px"></div>' +
-		'{{end}}' +
-		'{{else}}' +
-		'<ul>' +
-		'{{#each activities}}' +
+		'<div class="loading hidden" style="height: 50px"></div>' +
+		'<ul class="activities hidden">' +
+		'    <li class="empty">{{emptyMessage}}</li>' +
+		'</ul>' +
+		'<input type="button" class="showMore" value="{{moreLabel}}"' +
+		'</div>';
+	var ACTIVITY_TEMPLATE =
 		'    <li class="activity box">' +
 		'        <div class="activity-icon {{typeIconClass}}"></div>' +
 		'        <div class="activitysubject">{{{subject}}}</div>' +
@@ -29,46 +30,7 @@
 		'        {{/each}}' +
 		'        </div>' +
 		'        {{/if}}' +
-		'    </li>' +
-		'{{else}}' +
-		'    <li class="empty">{{emptyMessage}}</li>' +
-		'{{/each}}' +
-		'</ul>' +
-		'{{/if}}' +
-		'</div>';
-
-	/**
-	 * Format an activity model for display
-	 *
-	 * @param {OCA.Activity.ActivityModel} activity
-	 * @return {Object}
-	 */
-	function formatActivity(activity) {
-		var timestamp = moment(activity.get('datetime')).valueOf(),
-			output = {
-				subject: OCA.Activity.Formatter.parseMessage(activity.get('subject_prepared'), false),
-				formattedDate: OC.Util.relativeModifiedDate(timestamp),
-				formattedDateTooltip: OC.Util.formatDate(timestamp),
-				message: OCA.Activity.Formatter.parseMessage(activity.get('message_prepared'), false)
-			};
-
-		if (activity.has('typeicon')) {
-			output.typeIconClass = activity.get('typeicon') + ' svg';
-		}
-		/**
-		 * Disable previews in the rightside bar,
-		 * it's always the same image anyway.
-		if (activity.has('previews')) {
-			output.previews = _.map(activity.get('previews'), function(data) {
-				return {
-					previewClass: data.isMimeTypeIcon ? 'preview-mimetype-icon': '',
-					source: data.source
-				};
-			});
-		}
-		*/
-		return output;
-	}
+		'    </li>';
 
 	/**
 	 * @class OCA.Activity.ActivityTabView
@@ -77,11 +39,14 @@
 	 * Displays activity information for a given file
 	 *
 	 */
-	var ActivityTabView = OCA.Files.DetailTabView.extend(
-		/** @lends OCA.Activity.ActivityTabView.prototype */ {
+	var ActivityTabView = OCA.Files.DetailTabView.extend(/** @lends OCA.Activity.ActivityTabView.prototype */ {
 		id: 'activityTabView',
 		className: 'activityTabView tab',
 
+		events: {
+			'click .showMore': '_onClickShowMore'
+		},
+
 		_loading: false,
 
 		initialize: function() {
@@ -89,8 +54,8 @@
 			this.collection.setObjectType('files');
 			this.collection.on('request', this._onRequest, this);
 			this.collection.on('sync', this._onEndRequest, this);
-			this.collection.on('update', this._onChange, this);
 			this.collection.on('error', this._onError, this);
+			this.collection.on('add', this._onAddModel, this);
 		},
 
 		template: function(data) {
@@ -112,6 +77,7 @@
 			this._fileInfo = fileInfo;
 			if (this._fileInfo) {
 				this.collection.setObjectId(this._fileInfo.get('id'));
+				this.collection.reset();
 				this.collection.fetch();
 			} else {
 				this.collection.reset();
@@ -123,43 +89,105 @@
 		},
 
 		_onRequest: function() {
-			this._loading = true;
-			this.render();
+			if (this.collection.lastGivenId === 0) {
+				this.render();
+			}
+			this.$el.find('.showMore').addClass('hidden');
 		},
 
 		_onEndRequest: function() {
-			this._loading = false;
-			// empty result ?
-			if (!this.collection.length) {
-				// render now as there will be no update event
-				this.render();
+			this.$container.removeClass('hidden');
+			this.$el.find('.loading').addClass('hidden');
+			if (this.collection.length) {
+				this.$container.find('li.empty').addClass('hidden');
+			}
+			if (this.collection.hasMore) {
+				this.$el.find('.showMore').removeClass('hidden');
 			}
 		},
 
-		_onChange: function() {
-			this._loading = false;
-			this.render();
+		_onClickShowMore: function() {
+			this.collection.fetch({
+				reset: false
+			});
 		},
 
+		/**
+		 * Format an activity model for display
+		 *
+		 * @param {OCA.Activity.ActivityModel} activity
+		 * @return {Object}
+		 */
+		_formatItem: function(activity) {
+			var output = {
+				subject: OCA.Activity.Formatter.parseMessage(activity.get('subject_prepared'), false),
+				formattedDate: activity.getRelativeDate(),
+				formattedDateTooltip: activity.getFullDate(),
+				message: OCA.Activity.Formatter.parseMessage(activity.get('message_prepared'), false)
+			};
+
+			if (activity.has('typeicon')) {
+				output.typeIconClass = activity.get('typeicon') + ' svg';
+			}
+			/**
+			 * Disable previews in the rightside bar,
+			 * it's always the same image anyway.
+			 if (activity.has('previews')) {
+					output.previews = _.map(activity.get('previews'), function(data) {
+						return {
+							previewClass: data.isMimeTypeIcon ? 'preview-mimetype-icon': '',
+							source: data.source
+						};
+					});
+				}
+			 */
+			return output;
+		},
+
+		activityTemplate: function(params) {
+			if (!this._activityTemplate) {
+				this._activityTemplate = Handlebars.compile(ACTIVITY_TEMPLATE);
+			}
+
+			return this._activityTemplate(params);
+		},
+
+		_onAddModel: function(model, collection, options) {
+			var $el = $(this.activityTemplate(this._formatItem(model)));
+			if (!_.isUndefined(options.at) && collection.length > 1) {
+				this.$container.find('li').eq(options.at).before($el);
+			} else {
+				this.$container.append($el);
+			}
+
+			this._postRenderItem($el);
+		},
+
+		_postRenderItem: function($el) {
+			$el.find('.avatar').each(function() {
+				var element = $(this);
+				if (element.data('user-display-name')) {
+					element.avatar(element.data('user'), 28, undefined, false, undefined, element.data('user-display-name'));
+				} else if (element.data('user')) {
+					element.avatar(element.data('user'), 28);
+				}
+			});
+			$el.find('.has-tooltip').tooltip({
+				placement: 'bottom'
+			});
+		},
+
+
 		/**
 		 * Renders this details view
 		 */
 		render: function() {
 			if (this._fileInfo) {
 				this.$el.html(this.template({
-					loading: this._loading,
-					activities: this.collection.map(formatActivity),
-					emptyMessage: t('activity', 'No activities')
+					emptyMessage: t('activity', 'No activities'),
+					moreLabel: t('activity', 'Load more activities')
 				}));
-				this.$el.find('.avatar').each(function() {
-					var element = $(this);
-					element.avatar(element.data('user'), 28);
-				});
-				this.$el.find('.has-tooltip').tooltip({
-					placement: 'bottom'
-				});
-			} else {
-				// TODO: render placeholder text?
+				this.$container = this.$el.find('ul.activities');
 			}
 		}
 	});
