@@ -2,14 +2,10 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "Aktivität",
-    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
-    "Your feed URL is invalid" : "Deine Feed-URL ist ungültig",
-    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
-    "Mail" : "Mail",
-    "Stream" : "Stream",
     "Activities" : "Aktivitäten",
     "Error loading activities" : "Fehler beim Laden der Aktivitäten",
     "No activities" : "Keine Aktivitäten",
+    "Load more activities" : "Weitere Aktivitäten laden",
     ", " : ", ",
     "{parameterList} and {lastParameter}" : "{parameterList} und {lastParameter}",
     "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} und {linkStart}%n mehr{linkEnd}","{parameterList} und {linkStart}%n mehr{linkEnd}"],
@@ -18,6 +14,11 @@ OC.L10N.register(
     "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
     "Today" : "Heute",
     "Yesterday" : "Gestern",
+    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
+    "Your feed URL is invalid" : "Deine Feed-URL ist ungültig",
+    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
+    "Mail" : "Mail",
+    "Stream" : "Stream",
     "\"remote user\"" : "„Entfernter Benutzer“",
     "Activity notification" : "Benachrichtigung über die Aktivitäten",
     "All Activities" : "Alle Aktivitäten",
@@ -28,7 +29,7 @@ OC.L10N.register(
     "You are receiving this email because the following things happened at %s" : "Du erhältst diese E-Mail, da folgende Dinge auf %s geschehen sind",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
-    "List your own actions in the stream" : "Deine eigenen Aktivitäten im Stream auflisten",
+    "List your own file actions in the stream" : "Deine eigenen Datei-Aktivitäten im Stream auflisten",
     "Notify about your own actions via email" : "Über Deine eigenen Aktivitäten via E-Mail benachrichtigen",
     "You need to set up your email address before you can receive notification emails." : "Bevor Du E-Mail-Benachrichtigungen empfangen kannst, musst Du Deine E-Mail-Adresse einrichten.",
     "Send emails:" : "Sende E-Mails:",
