@@ -2,22 +2,23 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "Activité",
+    "Activities" : "Activité",
+    "Error loading activities" : "Erreur au chargement de l'activité",
+    "No activities" : "Aucune activité",
+    "Load more activities" : "Charger plus d'activités",
+    ", " : ", ",
+    "{parameterList} and {lastParameter}" : "{parameterList} et {lastParameter}",
+    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} et {linkStart}%n autre{linkEnd}","{parameterList} et {linkStart}%n autres{linkEnd}"],
+    "in {directory}" : "dans {directory}",
+    "This stream will show events like additions, changes & shares" : "Ce flux liste les événements tels que les ajouts, les modifications et les partages",
+    "There are no events for this filter" : "Il n'y a pas d'événement pour ce filtre",
+    "Today" : "Auj.",
+    "Yesterday" : "Hier",
     "Personal activity feed for %s" : "Flux d'activité personnel de %s",
     "Your feed URL is invalid" : "Votre adresse de fil d’activité n'est pas valide",
     "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
     "Mail" : "Mail",
     "Stream" : "Flux",
-    "Activities" : "Activité",
-    "Error loading activities" : "Erreur au chargement de l'activité",
-    "No activities" : "Aucune activité",
-    ", " : ", ",
-    "{parameterList} and {lastParameter}" : "{parameterList} et {lastParameter}",
-    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} et {linkStart}%n autre{linkEnd}","{parameterList} et {linkStart}%n autres{linkEnd}"],
-    "in {directory}" : "dans {directory}",
-    "This stream will show events like additions, changes & shares" : "Ce flux montre les événements tels que les ajouts, les modifications et les partages",
-    "There are no events for this filter" : "Il n'y a pas d'événement pour ce filtre",
-    "Today" : "Auj.",
-    "Yesterday" : "Hier",
     "\"remote user\"" : "\"utilisateur distant\"",
     "Activity notification" : "Notification d'activité",
     "All Activities" : "Toutes activités",
@@ -28,7 +29,7 @@ OC.L10N.register(
     "You are receiving this email because the following things happened at %s" : "Vous recevez ce message car l'activité suivante a eu lieu sur %s",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* et %n autre","* et %n autres"],
-    "List your own actions in the stream" : "Lister mes propres actions dans le flux",
+    "List your own file actions in the stream" : "Liste de vos propres actions dans le flux",
     "Notify about your own actions via email" : "M'informer de mes propres actions par courriel",
     "You need to set up your email address before you can receive notification emails." : "Il est nécessaire de configurer une adresse courriel avant de pouvoir recevoir les notifications par courriel.",
     "Send emails:" : "Envoyer des courriels :",
