@@ -21,14 +21,19 @@ OC.L10N.register(
     "Invalid directory." : "Direutoriu non válidu.",
     "Files" : "Ficheros",
     "All files" : "Tolos ficheros",
-    "Favorites" : "Favoritos",
+    "File could not be found" : "Nun s'atopó el ficheru",
     "Home" : "Casa",
     "Close" : "Zarrar",
+    "Favorites" : "Favoritos",
     "Upload cancelled." : "Xuba encaboxada.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
     "Total file size {size1} exceeds upload limit {size2}" : "El tamañu de ficheru total {size1} perpasa la llende de xuba {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
+    "Error uploading file \"{fileName}\": {message}" : "Fallu xubiendo'l ficheru \"{fileName}\": {message}",
     "Could not get result from server." : "Nun pudo obtenese'l resultáu del sirvidor.",
+    "Uploading..." : "Xubiendo...",
+    "..." : "...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "La xuba del ficheru ta en progresu. Si dexes agora la páxina, va encaboxase la xuba.",
     "Actions" : "Aiciones",
     "Download" : "Descargar",
@@ -42,6 +47,17 @@ OC.L10N.register(
     "Unable to determine date" : "Imposible determinar la fecha",
     "This operation is forbidden" : "La operación ta prohibida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, por favor verifica'l rexistru o contacta l'alministrador",
+    "Could not move \"{file}\", target exists" : "Nun pudo movese \"{file}\", destín yá esiste",
+    "Could not move \"{file}\"" : "Nun pudo movese \"{file}\"",
+    "{newName} already exists" : "{newName} yá esiste",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Nun pudo renomase \"{fileName}\", yá nun esiste",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nome \"{targetName}\" yá ta n'usu na carpeta \"{dir}\". Por favor, escueyi un nome diferente.",
+    "Could not rename \"{fileName}\"" : "Nun pudo renomase \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Nun pudo crease'l ficheru \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
+    "Could not create folder \"{dir}\"" : "Nun pudo crease la carpeta \"{dir}\"",
+    "Could not create folder \"{dir}\" because it already exists" : "Nun pudo crease la carpeta \"{dir}\" porque yá esiste",
+    "Error deleting file \"{fileName}\"." : "Fallu borrando'l ficheru \"{fileName}\".",
     "No entries in this folder match '{filter}'" : "Nun concasa nenguna entrada nesta carpeta '{filter}'",
     "Name" : "Nome",
     "Size" : "Tamañu",
@@ -63,6 +79,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
     "Favorited" : "Favoritos",
     "Favorite" : "Favoritu",
+    "Local link" : "Enllaz llocal",
     "Folder" : "Carpeta",
     "New folder" : "Nueva carpeta",
     "{newname} already exists" : "{newname} yá existe",
@@ -90,10 +107,12 @@ OC.L10N.register(
     "Maximum upload size" : "Tamañu máximu de xubida",
     "max. possible: " : "máx. posible:",
     "Save" : "Guardar",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM pue retrasase 5 minutos pa que los cambeos s'apliquen.",
+    "Missing permissions to edit from here." : "Falten permisos pa editar dende equí.",
     "Settings" : "Axustes",
+    "Show hidden files" : "Amosar ficheros ocultos",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Usa esta direición <a href=\"%s\" target=\"_blank\">p'acceder a los ficheros a traviés de WebDAV</a>",
-    "Cancel upload" : "Encaboxar xuba",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Usa esta direición <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">p'acceder a los dos Ficheros via WebDAV</a>",
     "No files in here" : "Nun hai nengún ficheru equí",
     "Upload some content or sync with your devices!" : "¡Xuba algún conteníu o sincroniza colos sos preseos!",
     "No entries found in this folder" : "Nenguna entrada en esta carpeta",
@@ -103,13 +122,6 @@ OC.L10N.register(
     "No favorites" : "Nengún favoritu",
     "Files and folders you mark as favorite will show up here" : "Los ficheros y carpetes que marque como favoritos apaecerán equí",
     "Text file" : "Ficheru de testu",
-    "New text file.txt" : "Nuevu testu ficheru.txt",
-    "Changed by %2$s" : "Modificáu por %2$s",
-    "Deleted by %2$s" : "Desaniciáu por %2$s",
-    "Restored by %2$s" : "Recuperáu por %2$s",
-    "You changed %1$s" : "Modificasti %1$s",
-    "You created %1$s" : "Creasti %1$s",
-    "You deleted %1$s" : "Desaniciasti %1$s",
-    "You restored %1$s" : "Recuperóse %1$s"
+    "New text file.txt" : "Nuevu testu ficheru.txt"
 },
 "nplurals=2; plural=(n != 1);");
