@@ -21,15 +21,19 @@ OC.L10N.register(
     "Invalid directory." : "Ungültiges Verzeichnis.",
     "Files" : "Dateien",
     "All files" : "Alle Dateien",
-    "Favorites" : "Favoriten",
+    "File could not be found" : "Datei konnte nicht gefunden werden",
     "Home" : "Zuhause",
     "Close" : "Schließen",
+    "Favorites" : "Favoriten",
     "Upload cancelled." : "Upload abgebrochen.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
     "Total file size {size1} exceeds upload limit {size2}" : "Die Gesamt-Größe {size1} überschreitet die Upload-Begrenzung {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Sie möchten {size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
     "Error uploading file \"{fileName}\": {message}" : "Fehler beim Hochladen der Datei \"{fileName}\": {message}",
     "Could not get result from server." : "Ergebnis konnte nicht vom Server abgerufen werden.",
+    "Uploading..." : "Hochladen…",
+    "..." : "...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn Sie die Seite jetzt verlassen, wird der Upload abgebrochen.",
     "Actions" : "Aktionen",
     "Download" : "Herunterladen",
@@ -75,6 +79,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
+    "Local link" : "Lokaler Link",
     "Folder" : "Ordner",
     "New folder" : "Neuer Ordner",
     "{newname} already exists" : "{newname} existiert bereits",
@@ -105,9 +110,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Bei PHP-FPM kann es 5 Minuten dauern, bis Änderungen angewendet sind.",
     "Missing permissions to edit from here." : "Fehlende Berechtigungen um von hier aus zu bearbeiten.",
     "Settings" : "Einstellungen",
+    "Show hidden files" : "Versteckte Dateien anzeigen",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Benutzen Sie diese Adresse, um <a href=\"%s\" target=\"_blank\">über WebDAV auf Ihre Dateien zuzugreifen</a>",
-    "Cancel upload" : "Upload abbrechen",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Benutzen Sie diese Adresse, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">über WebDAV auf Ihre Dateien zuzugreifen</a>",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie mit Ihren Geräten!",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
@@ -117,14 +122,6 @@ OC.L10N.register(
     "No favorites" : "Keine Favoriten",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
     "Text file" : "Textdatei",
-    "New text file.txt" : "Neue Textdatei file.txt",
-    "Changed by %2$s" : "Geändert von %2$s",
-    "Deleted by %2$s" : "Gelöscht durch %2$s",
-    "Restored by %2$s" : "Wiederhergestellt durch %2$s",
-    "Unable to set upload directory." : "Das Upload-Verzeichnis konnte nicht gesetzt werden.",
-    "You changed %1$s" : "Sie haben %1$s geändert",
-    "You created %1$s" : "Sie haben %1$s erstellt",
-    "You deleted %1$s" : "Sie haben %1$s gelöscht",
-    "You restored %1$s" : "Sie haben %1$s wiederhergestellt"
+    "New text file.txt" : "Neue Textdatei file.txt"
 },
 "nplurals=2; plural=(n != 1);");
