@@ -21,15 +21,19 @@ OC.L10N.register(
     "Invalid directory." : "Drejtori e pavlefshme.",
     "Files" : "Kartela",
     "All files" : "Krejt kartelat",
-    "Favorites" : "Të parapëlqyera",
+    "File could not be found" : "Kartela s’u gjet dot",
     "Home" : "Kreu",
     "Close" : "Mbylle",
+    "Favorites" : "Të parapëlqyera",
     "Upload cancelled." : "Ngarkimi u anulua.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "S’arrihet të ngarkohet {filename}, ngaqë është drejtori ose ka 0 bajte",
     "Total file size {size1} exceeds upload limit {size2}" : "Madhësia gjithsej e kartelës {size1} e tejkalon kufirin {size2} për ngarkimet",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nuk ka hapësirë të mjaftueshme, po ngarkoni {size1}, por ka vetëm {size2} të lira",
     "Error uploading file \"{fileName}\": {message}" : "Gabim në ngarkimin e kartelës \"{fileName}\": {message}",
     "Could not get result from server." : "S’mori dot përfundime nga shërbyesi.",
+    "Uploading..." : "Po ngarkohet...",
+    "..." : "...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Ngarkimi i kartelës është në punë e sipër. Largimi nga faqja do të anulojë ngarkimin.",
     "Actions" : "Veprime",
     "Download" : "Shkarkoje",
@@ -75,6 +79,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajte"],
     "Favorited" : "U kalua e parapëlqyer",
     "Favorite" : "E parapëlqyer",
+    "Local link" : "Lidhje vendore",
     "Folder" : "Dosje",
     "New folder" : "Dosje e re",
     "{newname} already exists" : "Ka tashmë një {newname}",
@@ -105,9 +110,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Me PHP-FPM mund të duhen 5 minuta që ndryshimet të hyjnë në fuqi.",
     "Missing permissions to edit from here." : "Mungojnë lejet për përpunim që nga këtu.",
     "Settings" : "Rregullime",
+    "Show hidden files" : "Shfaq kartela të fshehura",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Përdorni këtë adresë për <a href=\"%s\" target=\"_blank\">të hyrë te Kartelat tuaja përmes WebDAV-it</a>",
-    "Cancel upload" : "Anuloje ngarkimin",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Përdorni këtë adresë për <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">të hyrë te Kartelat tuaja përmes WebDAV-it</a>",
     "No files in here" : "S’ka kartela këtu",
     "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
     "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
@@ -117,13 +122,6 @@ OC.L10N.register(
     "No favorites" : "Pa të parapëlqyera",
     "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
     "Text file" : "Kartelë tekst",
-    "New text file.txt" : "Kartelë e re file.txt",
-    "Changed by %2$s" : "Ndryshuar nga %2$s",
-    "Deleted by %2$s" : "Fshirë nga %2$s",
-    "Restored by %2$s" : "Rikthyer nga %2$s",
-    "You changed %1$s" : "Ndryshuat %1$s",
-    "You created %1$s" : "Krijuat %1$s",
-    "You deleted %1$s" : "Fshitë %1$s",
-    "You restored %1$s" : "Rikthyet %1$s"
+    "New text file.txt" : "Kartelë e re file.txt"
 },
 "nplurals=2; plural=(n != 1);");
