@@ -1,12 +1,10 @@
 <div id="controls">
 		<div class="actions creatable hidden">
 			<div id="uploadprogresswrapper">
-				<div id="uploadprogressbar"></div>
-				<button class="stop icon-close" style="display:none">
-					<span class="hidden-visually">
-						<?php p($l->t('Cancel upload'))?>
-					</span>
-				</button>
+				<div id="uploadprogressbar">
+					<em class="label outer" style="display:none"><span class="desktop"><?php p($l->t('Uploading...'));?></span><span class="mobile"><?php p($l->t('...'));?></span></em>
+				</div>
+				<input type="button" class="stop icon-close" style="display:none" value="" />
 			</div>
 		</div>
 		<div id="file_action_panel"></div>
