@@ -4,8 +4,8 @@ OC.L10N.register(
     "Could not revert: %s" : "ไม่สามารถย้อนกลับ: %s",
     "Versions" : "รุ่น",
     "Failed to revert {file} to revision {timestamp}." : "{file} ล้มเหลวที่จะย้อนกลับ มีการแก้ไขเมื่อ {timestamp}",
-    "More versions..." : "รุ่นอื่นๆ ...",
-    "No other versions available" : "ไม่มีรุ่นอื่นๆ",
-    "Restore" : "คืนค่า"
+    "Restore" : "คืนค่า",
+    "No other versions available" : "ยังไม่มีรุ่นที่ใหม่กว่า",
+    "More versions..." : "รุ่นอื่นๆ ..."
 },
 "nplurals=1; plural=0;");
