@@ -1,22 +1,40 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "No s'ha pogut enviar correu als usuaris següents: %s",
-    "Turned on maintenance mode" : "Activat el mode de manteniment",
-    "Turned off maintenance mode" : "Desactivat el mode de manteniment",
-    "Updated database" : "Actualitzada la base de dades",
-    "Checked database schema update" : "S'ha comprobat l'actualització de l'esquema de la base de dades",
-    "Checked database schema update for apps" : "S'ha comprobat l'actualització de l'esquema de la base de dades per les apps",
-    "Updated \"%s\" to %s" : "Actualitzat \"%s\" a %s",
-    "Repair warning: " : "Advertiment de reparació:",
-    "Following incompatible apps have been disabled: %s" : "Les següents apps incompatibles s'han deshabilitat: %s",
-    "Following 3rd party apps have been disabled: %s" : "Les següents aplicacions de tercers han estat deshabilitades: %s",
+    "File is too big" : "El fitxer és massa gran",
     "Invalid file provided" : "L'arxiu proporcionat no és vàlid",
     "No image or file provided" : "No s'han proporcionat imatges o fitxers",
     "Unknown filetype" : "Tipus de fitxer desconegut",
     "Invalid image" : "Imatge no vàlida",
     "No temporary profile picture available, try again" : "No hi ha imatge temporal de perfil disponible, torneu a intentar-ho",
     "No crop data provided" : "No heu proporcionat dades del retall",
+    "No valid crop data provided" : "Les dades del retall proporcionades no són vàlides",
+    "Crop is not square" : "El retall no és quadrat",
+    "Couldn't reset password because the token is invalid" : "No es pot restablir la contrasenya perquè el testimoni no és vàlid",
+    "Couldn't reset password because the token is expired" : "No es pot restablir la contrasenya perquè el testimoni ha vençut",
+    "Couldn't send reset email. Please make sure your username is correct." : "No s'ha pogut enviar el correu de restabliment. Assegureu-vos que el vostre nom d'usuari és correcte.",
+    "%s password reset" : "restableix la contrasenya %s",
+    "Couldn't send reset email. Please contact your administrator." : "No s'ha pogut restablir el correu. Contacteu amb l'administrador.",
+    "Error loading tags" : "Error en carregar les etiquetes",
+    "Tag already exists" : "L'etiqueta ja existeix",
+    "Error deleting tag(s)" : "Error en eliminar etiqueta(s)",
+    "Error tagging" : "Error en etiquetar",
+    "Error untagging" : "Error en treure les etiquetes",
+    "Error favoriting" : "Error en posar a preferits",
+    "Error unfavoriting" : "Error en treure de preferits",
+    "Couldn't send mail to following users: %s " : "No s'ha pogut enviar correu als usuaris següents: %s",
+    "Preparing update" : "Preparant l'actualització",
+    "Repair warning: " : "Advertiment de reparació:",
+    "Repair error: " : "Error de reparació:",
+    "Turned on maintenance mode" : "Activat el mode de manteniment",
+    "Turned off maintenance mode" : "Desactivat el mode de manteniment",
+    "Maintenance mode is kept active" : "El mode de manteniment es manté activat",
+    "Updated database" : "Actualitzada la base de dades",
+    "Checked database schema update" : "S'ha comprobat l'actualització de l'esquema de la base de dades",
+    "Checked database schema update for apps" : "S'ha comprobat l'actualització de l'esquema de la base de dades per les apps",
+    "Updated \"%s\" to %s" : "Actualitzat \"%s\" a %s",
+    "Following apps have been disabled: %s" : "Les aplicacions següents s'han deshabilitat: %s",
+    "Already up to date" : "Ja actualitzat",
     "Sunday" : "Diumenge",
     "Monday" : "Dilluns",
     "Tuesday" : "Dimarts",
@@ -24,6 +42,20 @@ OC.L10N.register(
     "Thursday" : "Dijous",
     "Friday" : "Divendres",
     "Saturday" : "Dissabte",
+    "Sun." : "Dg.",
+    "Mon." : "Dl.",
+    "Tue." : "Dm.",
+    "Wed." : "Dc.",
+    "Thu." : "Dj.",
+    "Fri." : "Dv.",
+    "Sat." : "Ds.",
+    "Su" : "Dg",
+    "Mo" : "Dl",
+    "Tu" : "Dm",
+    "We" : "Dc",
+    "Th" : "Dj",
+    "Fr" : "Dv",
+    "Sa" : "Ds",
     "January" : "Gener",
     "February" : "Febrer",
     "March" : "Març",
@@ -36,9 +68,21 @@ OC.L10N.register(
     "October" : "Octubre",
     "November" : "Novembre",
     "December" : "Desembre",
+    "Jan." : "Gen.",
+    "Feb." : "Febr.",
+    "Mar." : "Març",
+    "Apr." : "Abr.",
+    "May." : "Maig",
+    "Jun." : "Juny",
+    "Jul." : "Jul.",
+    "Aug." : "Ag.",
+    "Sep." : "Set.",
+    "Oct." : "Oct.",
+    "Nov." : "Nov.",
+    "Dec." : "Des.",
     "Settings" : "Configuració",
     "Saving..." : "Desant...",
-    "Couldn't send reset email. Please contact your administrator." : "No s'ha pogut restablir el correu. Contacteu amb l'administrador.",
+    "seconds ago" : "segons enrere",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "L'enllaç per reiniciar la vostra contrasenya s'ha enviat al vostre correu. Si no el rebeu en un temps raonable comproveu les carpetes de spam. <br>Si no és allà, pregunteu a l'administrador local.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Els vostres fitxers estan encriptats. Si no heu habilitat la clau de recuperació no hi haurà manera de recuperar les dades després que reestabliu la contrasenya. <br />Si sabeu què fer, contacteu amb l'administrador abans de continuar.<br />Voleu continuar?",
     "I know what I'm doing" : "Sé el que faig",
@@ -66,54 +110,51 @@ OC.L10N.register(
     "So-so password" : "Contrasenya passable",
     "Good password" : "Contrasenya bona",
     "Strong password" : "Contrasenya forta",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "El servidor web no està configurat correctament per permetre la sincronització de fitxers perquè la interfície WebDAV sembla no funcionar correctament.",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Aquest servidor no té connexió a internet. Això significa que algunes de les característiques com el muntatge d'emmagatzemament extern, les notificacions quant a actualitzacions o la instal·lació d'aplicacions de tercers no funcionarà. L'accés remot a fitxers i l'enviament de correus electrònics podria tampoc no funcionar. Us suggerim que habiliteu la connexió a internet per aquest servidor si voleu tenir totes les característiques.",
     "Error occurred while checking server setup" : "Hi ha hagut un error en comprovar la configuració del servidor",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "La carpeta de dades i els vostres fitxers probablement són accessibles des d'Internet. El fitxer .htaccess no funciona. Us recomanem que configureu el servidor web de tal manera que la carpeta de dades no sigui accessible o que moveu la carpeta de dades fora de l'arrel de documents del servidor web.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Esteu accedint aquesta web a través de HTTP. Us recomanem que configureu el servidor per requerir HTTPS tal i com es descriu als <a href=\"{docUrl}\">consells de seguretat</a>",
     "Shared" : "Compartit",
     "Shared with {recipients}" : "Compartit amb {recipients}",
-    "Share" : "Comparteix",
     "Error" : "Error",
     "Error while sharing" : "Error en compartir",
     "Error while unsharing" : "Error en deixar de compartir",
-    "Error while changing permissions" : "Error en canviar els permisos",
-    "Shared with you and the group {group} by {owner}" : "Compartit amb vos i amb el grup {group} per {owner}",
-    "Shared with you by {owner}" : "Compartit amb vos per {owner}",
-    "Share with users or groups …" : "Comparteix amb usuaris o grups ...",
-    "Share with users, groups or remote users …" : "Comparteix amb usuaris, grups o usuaris remots ...",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir amb la gent en altres ownClouds utilitzant la sintaxi username@example.com/owncloud",
-    "Share link" : "Enllaç de compartició",
+    "Error setting expiration date" : "Error en establir la data de venciment",
     "The public link will expire no later than {days} days after it is created" : "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
-    "Link" : "Enllaç",
-    "Password protect" : "Protegir amb contrasenya",
-    "Password" : "Contrasenya",
-    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
-    "Allow editing" : "Permetre edició",
-    "Email link to person" : "Enllaç per correu electrónic amb la persona",
-    "Send" : "Envia",
     "Set expiration date" : "Estableix la data de venciment",
     "Expiration" : "Expiració",
     "Expiration date" : "Data de venciment",
-    "An error occured. Please try again" : "Va ocórrer un error. Per favor, intenta-ho de nou",
-    "Adding user..." : "Afegint usuari...",
-    "group" : "grup",
-    "remote" : "remot",
+    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
     "Resharing is not allowed" : "No es permet compartir de nou",
-    "Shared in {item} with {user}" : "Compartit en {item} amb {user}",
-    "Unshare" : "Deixa de compartir",
-    "notify by email" : "notifica per correu electrònic",
-    "can share" : "pot compartir",
-    "can edit" : "pot editar",
-    "access control" : "control d'accés",
-    "create" : "crea",
-    "change" : "cambi",
-    "delete" : "elimina",
-    "Password protected" : "Protegeix amb contrasenya",
-    "Error unsetting expiration date" : "Error en eliminar la data de venciment",
-    "Error setting expiration date" : "Error en establir la data de venciment",
+    "Share link" : "Enllaç de compartició",
+    "Link" : "Enllaç",
+    "Password protect" : "Protegir amb contrasenya",
+    "Password" : "Contrasenya",
+    "Allow editing" : "Permetre edició",
+    "Email link to person" : "Enllaç per correu electrónic amb la persona",
+    "Send" : "Envia",
     "Sending ..." : "Enviant...",
     "Email sent" : "El correu electrónic s'ha enviat",
+    "Shared with you and the group {group} by {owner}" : "Compartit amb vos i amb el grup {group} per {owner}",
+    "Shared with you by {owner}" : "Compartit amb vos per {owner}",
+    "group" : "grup",
+    "remote" : "remot",
+    "notify by email" : "notifica per correu electrònic",
+    "Unshare" : "Deixa de compartir",
+    "can share" : "pot compartir",
+    "can edit" : "pot editar",
+    "create" : "crea",
+    "change" : "canvi",
+    "delete" : "elimina",
+    "access control" : "control d'accés",
+    "Share" : "Comparteix",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir amb la gent en altres ownClouds utilitzant la sintaxi username@example.com/owncloud",
     "Warning" : "Avís",
+    "Delete" : "Esborra",
+    "Rename" : "Reanomena",
     "The object type is not specified." : "No s'ha especificat el tipus d'objecte.",
     "Enter new" : "Escriu nou",
-    "Delete" : "Esborra",
     "Add" : "Afegeix",
     "Edit tags" : "Edita etiquetes",
     "Error loading dialog template: {error}" : "Error en carregar la plantilla de diàleg: {error}",
@@ -124,32 +165,16 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Hola {name}, el temps és {weather}",
     "Hello {name}" : "Hola {name}",
     "_download %n file_::_download %n files_" : ["descarregar l'arxiu %n","descarregar arxius %n "],
-    "Updating {productName} to version {version}, this may take a while." : "Actualitzant {productName} a la versió {version}. Pot trigar una estona.",
     "Please reload the page." : "Carregueu la pàgina de nou.",
-    "The update was unsuccessful. " : "La actualització no ha tingut èxit",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "L'actualització ha estat incorrecte. Comuniqueu aquest error a <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">la comunitat ownCloud</a>.",
+    "The update was successful. There were warnings." : "La actualització ha estat exitosa. Hi ha alertes.",
     "The update was successful. Redirecting you to ownCloud now." : "L'actualització ha estat correcte. Ara us redirigim a ownCloud.",
-    "Couldn't reset password because the token is invalid" : "No es pot restablir la contrasenya perquè el testimoni no és vàlid",
-    "Couldn't send reset email. Please make sure your username is correct." : "No s'ha pogut enviar el correu de restabliment. Assegureu-vos que el vostre nom d'usuari és correcte.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "No s'ha pogut enviar el correu de restabliment perquè no hi ha cap correu electrònic per aquest usuari. Contacteu amb l'administrador.",
-    "%s password reset" : "restableix la contrasenya %s",
-    "Use the following link to reset your password: {link}" : "Useu l'enllaç següent per restablir la contrasenya: {link}",
-    "New password" : "Contrasenya nova",
-    "New Password" : "Contrasenya nova",
-    "Reset password" : "Reinicialitza la contrasenya",
     "Searching other places" : "Buscant altres ubicacions",
-    "_{count} search result in other places_::_{count} search results in other places_" : ["{count} resultat de cerca en altres ubicacions","{count} resultats de cerca en altres ubicacions"],
     "Personal" : "Personal",
     "Users" : "Usuaris",
     "Apps" : "Aplicacions",
     "Admin" : "Administració",
     "Help" : "Ajuda",
-    "Error loading tags" : "Error en carregar les etiquetes",
-    "Tag already exists" : "L'etiqueta ja existeix",
-    "Error deleting tag(s)" : "Error en eliminar etiqueta(s)",
-    "Error tagging" : "Error en etiquetar",
-    "Error untagging" : "Error en treure les etiquetes",
-    "Error favoriting" : "Error en posar a preferits",
-    "Error unfavoriting" : "Error en treure de preferits",
     "Access forbidden" : "Accés prohibit",
     "File not found" : "No s'ha trobat l'arxiu",
     "The specified document has not been found on the server." : "El document especificat no s'ha trobat al servidor.",
@@ -169,20 +194,23 @@ OC.L10N.register(
     "Message: %s" : "Missatge: %s",
     "File: %s" : "Fitxer: %s",
     "Line: %s" : "Línia: %s",
+    "Trace" : "Traça",
     "Security warning" : "Advertiment de seguretat",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els seus fitxers probablement són accessibles des d'internet perquè el fitxer .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Per informació de com configurar el servidor, comproveu la <a href=\"%s\" target=\"_blank\">documentació</a>.",
     "Create an <strong>admin account</strong>" : "Crea un <strong>compte d'administrador</strong>",
     "Username" : "Nom d'usuari",
     "Storage & database" : "Emmagatzematge i base de dades",
     "Data folder" : "Carpeta de dades",
     "Configure the database" : "Configura la base de dades",
     "Only %s is available." : "Només hi ha disponible %s",
+    "Install and activate additional PHP modules to choose other database types." : "Instal·la i activa mòduls PHP addicionals per seleccionar altres tipus de bases de dades.",
+    "For more details check out the documentation." : "Per més detalls consulteu la documentació.",
     "Database user" : "Usuari de la base de dades",
     "Database password" : "Contrasenya de la base de dades",
     "Database name" : "Nom de la base de dades",
     "Database tablespace" : "Espai de taula de la base de dades",
     "Database host" : "Ordinador central de la base de dades",
+    "Performance warning" : "Alerta de rendiment",
     "SQLite will be used as database." : "SQLite s'utilitzarà com a base de dades.",
     "For larger installations we recommend to choose a different database backend." : "Per a instal·lacions més grans es recomana triar una base de dades diferent.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'ús de SQLite està desaconsellat especialment quan s'usa el client d'escriptori per sincronitzar els fitxers.",
@@ -190,28 +218,33 @@ OC.L10N.register(
     "Finishing …" : "Acabant...",
     "Need help?" : "Necessites ajuda?",
     "See the documentation" : "Consulti la documentació",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ei, <br><br>només fer-vos saber que %s us ha comparti <strong>%s</strong>. <br><a href=\"%s\">Mireu-ho!</a>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicació requereix Javascript per al seu correcte funcionament . Per favor, {linkstart}habiliti Javascript{linkend} i torni a carregar la pàgina.",
     "Log out" : "Surt",
     "Search" : "Cerca",
     "Server side authentication failed!" : "L'autenticació del servidor ha fallat!",
     "Please contact your administrator." : "Contacteu amb l'administrador.",
-    "An internal error occured." : "S'ha produït un error intern.",
     "Please try again or contact your administrator." : "Intenti-ho de nou o posi's en contacte amb el seu administrador.",
-    "Forgot your password? Reset it!" : "Heu oblidat la contrasenya? Restabliu-la!",
-    "remember" : "recorda'm",
     "Log in" : "Inici de sessió",
+    "Wrong password. Reset it?" : "Contrasenya incorrecta. Voleu restablir-la?",
+    "Wrong password." : "Contrasenya incorrecta.",
+    "Stay logged in" : "Mantén la sessió connectada",
     "Alternative Logins" : "Acreditacions alternatives",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ei, <br><br>només fer-vos saber que %s us ha comparti <strong>%s</strong>. <br><a href=\"%s\">Mireu-ho!</a>",
+    "Use the following link to reset your password: {link}" : "Useu l'enllaç següent per restablir la contrasenya: {link}",
+    "New password" : "Contrasenya nova",
+    "New Password" : "Contrasenya nova",
+    "Reset password" : "Reinicialitza la contrasenya",
     "This ownCloud instance is currently in single user mode." : "La instància ownCloud està en mode d'usuari únic.",
     "This means only administrators can use the instance." : "Això significa que només els administradors poden usar la instància.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o apareix inesperadament.",
     "Thank you for your patience." : "Gràcies per la paciència.",
     "You are accessing the server from an untrusted domain." : "Esteu accedint al servidor des d'un domini no fiable",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contacteu amb l'administrador. Si sou un administrador d'aquesta instància, configureu el paràmetre \"trusted_domain\" a config/config.php. Hi ha un exemple de configuració a config/config.sampe.php",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En funció de la teva configuració, com a administrador podries utilitzar el botó d'abaix per confiar en aquest domini.",
     "Add \"%s\" as trusted domain" : "Afegeix \"%s\" com a domini de confiança",
-    "%s will be updated to version %s." : "%s s'actualitzarà a la versió %s.",
-    "The following apps will be disabled:" : "Les següents aplicacions es desactivaran:",
+    "App update required" : "Cal que actualitzeu la aplicació",
+    "%s will be updated to version %s" : "%s s'actualitzarà a la versió %s",
+    "These apps will be updated:" : "Aquestes aplicacions s'actualitzaran:",
+    "These incompatible apps will be disabled:" : "Aquestes aplicacions incompatibles es desactivaran:",
     "The theme %s has been disabled." : "S'ha desactivat el tema %s",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assegureu-vos que heu fet una còpia de seguretat de la base de dades, del fitxer de configuració i de la carpeta de dades abans de continuar.",
     "Start update" : "Inicia l'actualització",
