@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "An folgende Benutzer konnte keine E-Mail gesendet werden: %s",
-    "Preparing update" : "Update vorbereiten",
-    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet ",
-    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
-    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
-    "Updating database schema" : "Das Datenbankschema wird aktualisiert",
-    "Updated database" : "Datenbank aktualisiert",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
-    "Checked database schema update" : "Datenbankschema-Aktualisierung überprüft",
-    "Checking updates of apps" : "Es wird nach Updates für die Apps gesucht",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
-    "Checked database schema update for apps" : "Datenbankschema-Aktualisierung für Apps überprüft",
-    "Updated \"%s\" to %s" : "„%s“ zu %s aktualisiert",
-    "Repair warning: " : "Reperaturwarnung:",
-    "Repair error: " : "Reperaturfehler:",
-    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
-    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
-    "Starting code integrity check" : "Code-Integrität wird überprüft",
-    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
-    "%s (3rdparty)" : "%s (Drittanbieter)",
-    "%s (incompatible)" : "%s (inkompatibel)",
-    "Following apps have been disabled: %s" : "Die folgenden Apps sind deaktiviert worden: %s",
-    "Already up to date" : "Bereits aktuell",
     "Please select a file." : "Bitte wählen Sie eine Datei aus.",
     "File is too big" : "Datei ist zu groß",
     "Invalid file provided" : "Ungültige Datei zur Verfügung gestellt",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Es konnte keine E-Mail verschickt werden um das Passwort zurückzusetzten, da keine E-Mail im Benutzerkonto hinterlegt ist. Bitte kontaktieren Sie den Administrator.",
     "%s password reset" : "%s-Passwort zurücksetzen",
     "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
+    "Error loading tags" : "Fehler beim Laden der Schlagwörter",
+    "Tag already exists" : "Schlagwort ist bereits vorhanden",
+    "Error deleting tag(s)" : "Fehler beim Löschen des Schlagwortes bzw. der Schlagwörter",
+    "Error tagging" : "Fehler beim Hinzufügen der Schlagwörter",
+    "Error untagging" : "Fehler beim Entfernen der Schlagwörter",
+    "Error favoriting" : "Fehler beim Hinzufügen zu den Favoriten",
+    "Error unfavoriting" : "Fehler beim Entfernen aus den Favoriten",
+    "Couldn't send mail to following users: %s " : "An folgende Benutzer konnte keine E-Mail gesendet werden: %s",
+    "Preparing update" : "Update vorbereiten",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Reperaturwarnung:",
+    "Repair error: " : "Reperaturfehler:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Da automatische Updates in der config.php deaktivert sind, nutzen Sie bitte den Updater über die Kommandozeile.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Überprüfe Tabelle %s",
+    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet ",
+    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
+    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
+    "Updating database schema" : "Das Datenbankschema wird aktualisiert",
+    "Updated database" : "Datenbank aktualisiert",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
+    "Checked database schema update" : "Datenbankschema-Aktualisierung überprüft",
+    "Checking updates of apps" : "Es wird nach Updates für die Apps gesucht",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
+    "Checked database schema update for apps" : "Datenbankschema-Aktualisierung für Apps überprüft",
+    "Updated \"%s\" to %s" : "„%s“ zu %s aktualisiert",
+    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
+    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
+    "Starting code integrity check" : "Code-Integrität wird überprüft",
+    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
+    "%s (3rdparty)" : "%s (Drittanbieter)",
+    "%s (incompatible)" : "%s (inkompatibel)",
+    "Following apps have been disabled: %s" : "Die folgenden Apps sind deaktiviert worden: %s",
+    "Already up to date" : "Bereits aktuell",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
@@ -86,7 +96,9 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Es gab Probleme bei der Code Integritätsprüfung. Mehr Information...</a>",
     "Settings" : "Einstellungen",
+    "Problem loading page, reloading in 5 seconds" : "Problem beim Laden der Seite, Seite wird in 5 Sekunden nochmals geladen",
     "Saving..." : "Speichervorgang…",
     "Dismiss" : "Ausblenden",
     "seconds ago" : "Gerade eben",
@@ -118,11 +130,18 @@ OC.L10N.register(
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ihr Webserver ist noch nicht hinreichend für Datei-Synchronisation konfiguriert, weil die WebDAV-Schnittstelle vermutlich defekt ist.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Dein Webserver ist nicht richtig konfiguriert um \"{url}\" aufzulösen. Weitere Informationen hierzu finden Sie in unserer a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server hat keine funktionierende Internetverbindung. Dies bedeutet, dass einige Funktionen wie das Einhängen externen Speicherplatzes, Update-Benachrichtigungen oder die Installation von Drittanbieter-Apps nicht funktionieren werden. Der Fernzugriff auf Dateien und der Versand von E-Mail-Benachrichtigungen kann ebenfalls nicht funktionieren. Es wird empfohlen, die Internetverbindung dieses Servers zu aktivieren, wenn Sie alle Funktionen nutzen möchten.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Es wurde kein Memory Cache konfiguriert. Um die Leistung zu verbessern, konfigurieren Sie bitte einen Cache-Speicher, sofern vorhanden. Weitere Informationen finden Sie in unserer <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a>.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Es wurde kein PHP Memory Cache konfiguriert. Konfiguriere zur Erhöhung der Leistungsfähigkeit, soweit verfügbar, einen Memory Cache. Weitere Informationen finden Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ist von PHP nicht lesbar, wovon aus Sicherheitsgründen dringend abgeraten wird. Weitere Informationen hierzu finden Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Sie verwenden im Moment PHP {version}. Wir empfehlen ein Upgrade ihrer PHP Version, um die <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">Geschwindigkeits- und Sicherheitsupdates zu nutzen, welche von der PHP Gruppe bereitgestellt werden</a>, sobald diese ihre Distribution diese unterstützt.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Die Einstellung der Reverse Proxy Kopfzeile is falsch oder Sie greifen über einen gesicherten Proxy auf ownCloud zu. Falls Sie nicht über einen gesicherten Proxy auf ownCloud zugreifen handelt es sich um eine Sicherheitslücke, die es Angreifern erlaubt ihre IP-Adresse ownCloud gegenüber als sichtbar darzustellen. Weitere Informationen hierzu finden Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcache ist als verteilter Cache konfiguriert, aber das falsche PHP Modul \"memcache\" ist installiert. \\OC\\Memcache\\Memcached unterstützt nud \"memcached\" und nicht \"memcache\". Siehe <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached Wiki über beide Module</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Manche Dateien haben die Integritätsprüfung nicht bestanden. Weitere Informationen um den Fehler zu behen finden Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste der ungültigen Dateien...</a> / <a href=\"{rescanEndpoint}\">Erneut scannen…</a>)",
     "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, Ihren Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass Sie es aus dem Document-Root-Verzeichnis des Webservers herausverschieben.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Der „{header}“-HTTP-Header ist nicht so konfiguriert, dass er „{expected}“ entspricht. Dies ist ein potentielles Sicherheitsrisiko und es wird empfohlen, diese Einstellung zu ändern.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Der „Strict-Transport-Security“-HTTP-Header ist nicht auf mindestens „{seconds}“ Sekunden eingestellt. Für mehr Sicherheit wird das Aktivieren von HSTS empfohlen, wie es in unseren <a href=\"{docUrl}\" rel=\"noreferrer\">Sicherheitshinweisen</a> erläutert ist.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Sie greifen auf diese Site über HTTP zu. Wir raten dringend dazu, Ihren Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in unseren <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
     "Shared" : "Geteilt",
     "Shared with {recipients}" : "Geteilt mit {recipients}",
@@ -135,8 +154,6 @@ OC.L10N.register(
     "Expiration" : "Ablaufdatum",
     "Expiration date" : "Ablaufdatum",
     "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
-    "Sending ..." : "Senden…",
-    "Email sent" : "E-Mail gesendet",
     "Resharing is not allowed" : "Das Weiterverteilen ist nicht erlaubt",
     "Share link" : "Link teilen",
     "Link" : "Link",
@@ -145,6 +162,9 @@ OC.L10N.register(
     "Allow editing" : "Bearbeitung erlauben",
     "Email link to person" : "Link per E-Mail verschicken",
     "Send" : "Senden",
+    "Sending ..." : "Senden…",
+    "Email sent" : "E-Mail gesendet",
+    "Send link via email" : "Link als E-Mail verschicken",
     "Shared with you and the group {group} by {owner}" : "Von {owner} mit Ihnen und der Gruppe {group} geteilt.",
     "Shared with you by {owner}" : "Von {owner} mit Ihnen geteilt.",
     "group" : "Gruppe",
@@ -157,15 +177,25 @@ OC.L10N.register(
     "change" : "Ändern",
     "delete" : "löschen",
     "access control" : "Zugriffskontrolle",
+    "Could not unshare" : "Freigabe konnte nicht aufgehoben werden",
+    "Share details could not be loaded for this item." : "Die Freigabedetails konnten für dieses Element nicht geladen werden.",
     "No users or groups found for {search}" : "Keine Benutzer oder Gruppen für {search} gefunden",
-    "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
+    "No users found for {search}" : "Keine Benutzer für {search} gefunden",
+    "An error occurred. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
+    "{sharee} (group)" : "{sharee} (Gruppe)",
+    "{sharee} (at {server})" : "{sharee} (über {server})",
+    "{sharee} (remote)" : "{sharee} (entfernt)",
     "Share" : "Teilen",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
-    "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
-    "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
+    "Share with users…" : "Mit Benutzern teilen…",
+    "Share with users, groups or remote users…" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
+    "Share with users or groups…" : "Mit Benutzern oder Gruppen teilen…",
+    "Share with users or remote users…" : "Mit Benutzern oder entfernten Benutzern teilen…",
+    "Error removing share" : "Fehler beim Entfernen der Freigabe",
     "Warning" : "Warnung",
     "Error while sending notification" : "Fehler beim Senden der Benachrichtigung",
-    "not assignable" : "nicht zuweisbar",
+    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
+    "restricted" : "Eingeschränkt",
     "invisible" : "unsichtbar",
     "({scope})" : "({scope})",
     "Delete" : "Löschen",
@@ -182,12 +212,14 @@ OC.L10N.register(
     "sunny" : "Sonnig",
     "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
     "Hello {name}" : "Hallo {name}",
+    "new" : "Neu",
     "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Das Upgrade läuft noch , diese Seite zu verlassen könnte das Verfahren in einigen Umgebungen unterbrechen.",
-    "Updating {productName} to version {version}, this may take a while." : "{productName} wird auf Version {version} aktualisiert. Das könnte eine Weile dauern.",
+    "Updating to {version}" : "Aktualisierung auf {version}",
     "An error occurred." : "Ein Fehler ist aufgetreten.",
     "Please reload the page." : "Bitte laden Sie die Seite neu.",
-    "The update was unsuccessful. " : "Die Aktualisierung war nicht erfolgreich.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Das Update war nicht erfolgreich. Für mehr Informationen <a href=\"{url}\">lesen Sie unseren Forenbeitrag</a> zu diesem Thema.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melden Sie dieses Problem an die <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud Community</a>.",
     "The update was successful. There were warnings." : "Das Update war erfolgreich. Warnungen wurden ausgegeben.",
     "The update was successful. Redirecting you to ownCloud now." : "Das Update war erfolgreich. Sie werden nun zu ownCloud weitergeleitet.",
     "Searching other places" : "Andere Orte durchsuchen",
@@ -198,13 +230,6 @@ OC.L10N.register(
     "Apps" : "Apps",
     "Admin" : "Administrator",
     "Help" : "Hilfe",
-    "Error loading tags" : "Fehler beim Laden der Schlagwörter",
-    "Tag already exists" : "Schlagwort ist bereits vorhanden",
-    "Error deleting tag(s)" : "Fehler beim Löschen des Schlagwortes bzw. der Schlagwörter",
-    "Error tagging" : "Fehler beim Hinzufügen der Schlagwörter",
-    "Error untagging" : "Fehler beim Entfernen der Schlagwörter",
-    "Error favoriting" : "Fehler beim Hinzufügen zu den Favoriten",
-    "Error unfavoriting" : "Fehler beim Entfernen aus den Favoriten",
     "Access forbidden" : "Zugriff verboten",
     "File not found" : "Datei nicht gefunden",
     "The specified document has not been found on the server." : "Das ausgewählte Dokument wurde auf dem Server nicht gefunden.",
@@ -227,7 +252,7 @@ OC.L10N.register(
     "Trace" : "Ablauf",
     "Security warning" : "Sicherheitshinweis",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Informationen zum richtigen Konfigurieren Ihres Servers können Sie der <a href=\"%s\" target=\"_blank\">Dokumentation</a> entnehmen.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Informationen zum richtigen Konfigurieren Ihres Servers können Sie der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Dokumentation</a> entnehmen.",
     "Create an <strong>admin account</strong>" : "<strong>Administrator-Konto</strong> anlegen",
     "Username" : "Benutzername",
     "Storage & database" : "Speicher & Datenbank",
@@ -255,8 +280,9 @@ OC.L10N.register(
     "Search" : "Suche",
     "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
     "Please contact your administrator." : "Bitte kontaktieren Sie Ihren Administrator.",
-    "An internal error occured." : "Es ist ein interner Fehler aufgetreten.",
+    "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
     "Please try again or contact your administrator." : "Bitte versuchen Sie es noch einmal oder kontaktieren Sie Ihren Administrator.",
+    "Username or email" : "Benutzername oder E-Mail",
     "Log in" : "Einloggen",
     "Wrong password. Reset it?" : "Falsches Passwort. Soll es zurückgesetzt werden?",
     "Wrong password." : "Falsches Passwort.",
@@ -270,7 +296,13 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Das bedeutet, dass diese Instanz nur von Administratoren benutzt werden kann.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktieren Sie Ihren Systemadministrator, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
     "Thank you for your patience." : "Vielen Dank für Ihre Geduld.",
+    "Two-step verification" : "Bestätigung in zwei Schritten",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Die erweiterte Sicherheit wurde für Ihr Konto aktiviert. Bitte authentifizieren Sie sich mit einem zweiten Faktor. ",
+    "Cancel login" : "Anmelden abbrechen",
+    "Please authenticate using the selected factor." : "Bitte authentifizieren Sie sich mit dem ausgewählten zweiten Faktor. ",
+    "An error occured while verifying the token" : "Es ist ein Fehler bei der Verifizierung des Tokens aufgetreten",
     "You are accessing the server from an untrusted domain." : "Sie greifen von einer nicht vertrauenswürdigen Domain auf den Server zu.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Bitte kontaktieren Sie Ihren Administrator. Wenn Sie Administrator dieser Instanz sind, konfigurieren Sie bitte die „trusted_domain“-Einstellung in config/config.php. Eine Beispielkonfiguration wird unter config/config.sample.php bereitgestellt.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Wenn es Ihre Konfiguration zulässt, können Sie als Administrator gegebenenfalls den Button unten benutzen, um diese Domain als vertrauenswürdig einzustufen.",
     "Add \"%s\" as trusted domain" : "„%s“ als vertrauenswürdige Domain hinzufügen",
     "App update required" : "App-Update notwendig",
@@ -281,14 +313,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Stellen Sie vor dem Fortsetzen bitte sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
     "Start update" : "Aktualisierung starten",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Zur Vermeidung von Zeitüberschreitungen bei größeren Installationen können Sie stattdessen den folgenden Befehl in Ihrem Installationsverzeichnis ausführen:",
+    "Detailed logs" : "Detaillierte Fehlermeldungen",
+    "Update needed" : "Update erforderlich",
+    "Please use the command line updater because you have a big instance." : "Da Sie eine große Instanz von Owncloud besitzt, nutzen Sie bitte den Updater über die Kommandozeile.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schauen Sie bitte in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese %s-Instanz befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
-    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist.",
-    "Could not unshare" : "Freigabe konnte nicht aufgehoben werden",
-    "Error loading file picker template: {error}" : "Fehler beim Laden der Dateiauswahlvorlage: {error}",
-    "Error removing share" : "Fehler beim Entfernen der Freigabe",
-    "Fri." : "Fr",
-    "Mon." : "Mo",
-    "Password can not be changed. Please contact your administrator." : "Passwort kann nicht geändert werden. Bitte kontaktieren Sie Ihren Administrator.",
-    "Sat." : "Sa"
+    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist."
 },
 "nplurals=2; plural=(n != 1);");
