@@ -1,13 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Nije moguće slanje pošte sljedećim korisnicima: %s",
-    "Turned on maintenance mode" : "Način rada za održavanje uključen",
-    "Turned off maintenance mode" : "Način rada za održavanje isključen",
-    "Updated database" : " Baza podataka ažurirana",
-    "Checked database schema update" : "Provjereno ažuriranje sheme  baze podataka",
-    "Checked database schema update for apps" : "Provjereno ažuriranje sheme baze podataka za aplikacije",
-    "Updated \"%s\" to %s" : "Ažurirano \"%s\" u %s",
     "No image or file provided" : "Nijedna slika ili datoteka nije dobavljena",
     "Unknown filetype" : "Vrsta datoteke nepoznata",
     "Invalid image" : "Slika neispravna",
@@ -17,6 +10,20 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Resetiranu e-poštu nije moguće poslati.Molimo provjerite ispravnost svoga korisničkog imena.",
     "%s password reset" : "%s lozinka resetirana",
     "Couldn't send reset email. Please contact your administrator." : "Nije mogće poslati resetiranu poštu. MOlimo kontaktirajte svog administratora.",
+    "Error loading tags" : "Pogrešno učitavanje oznaka",
+    "Tag already exists" : "Oznaka već postoji",
+    "Error deleting tag(s)" : "Pogrešno brisanje oznake (oznaka)",
+    "Error tagging" : "Pogrešno označavanje",
+    "Error untagging" : "Pogrešno uklanjanje oznaka",
+    "Error favoriting" : "Pogrešno dodavanje u favorite",
+    "Error unfavoriting" : "Pogrešno uklanjanje iz favorita",
+    "Couldn't send mail to following users: %s " : "Nije moguće slanje pošte sljedećim korisnicima: %s",
+    "Turned on maintenance mode" : "Način rada za održavanje uključen",
+    "Turned off maintenance mode" : "Način rada za održavanje isključen",
+    "Updated database" : " Baza podataka ažurirana",
+    "Checked database schema update" : "Provjereno ažuriranje sheme  baze podataka",
+    "Checked database schema update for apps" : "Provjereno ažuriranje sheme baze podataka za aplikacije",
+    "Updated \"%s\" to %s" : "Ažurirano \"%s\" u %s",
     "Sunday" : "Nedjelja",
     "Monday" : "Ponedjeljak",
     "Tuesday" : "Utorak",
@@ -98,8 +105,6 @@ OC.L10N.register(
     "Expiration" : "Istjeće",
     "Expiration date" : "Datum isteka",
     "Choose a password for the public link" : "Odaberite lozinku za javnu vezu",
-    "Sending ..." : "Slanje...",
-    "Email sent" : "E-pošta poslana",
     "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
     "Share link" : "Podijelite vezu",
     "Link" : "Poveznica",
@@ -108,6 +113,8 @@ OC.L10N.register(
     "Allow editing" : "Omogući uređivanje",
     "Email link to person" : "Pošaljite osobi vezu e-poštom",
     "Send" : "Pošaljite",
+    "Sending ..." : "Slanje...",
+    "Email sent" : "E-pošta poslana",
     "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
     "Shared with you by {owner}" : "S vama podijelio {owner}",
     "group" : "Grupa",
@@ -120,11 +127,8 @@ OC.L10N.register(
     "change" : "promijeni",
     "delete" : "Izbrišite",
     "access control" : "Kontrola pristupa",
-    "An error occured. Please try again" : "Dogodila se pogreška. Molimo Vas, pokušajte ponovno. ",
     "Share" : "Podijelite",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Podijelite sa korisnicima drugoga ownClouda koristeći format korisnickoime@primjer.com/owncloud",
-    "Share with users or groups …" : "Podijeli sa korisnicima ili grupama ...",
-    "Share with users, groups or remote users …" : "Podijeli sa korisnicima, grupama ili udaljenim korisnicima ...",
     "Warning" : "Upozorenje",
     "Delete" : "Izbrišite",
     "Rename" : "Preimenujte",
@@ -140,9 +144,7 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Pozdrav {name}, vrijeme je {weather}",
     "Hello {name}" : "Pozdrav  {name}",
     "_download %n file_::_download %n files_" : ["preuzimanje %n datoteke","preuzimanje %n datoteke","preuzimanje %n datoteka"],
-    "Updating {productName} to version {version}, this may take a while." : "Uređivanje {productName} u verziiju {version}, to može potrajati neko vrijeme.",
     "Please reload the page." : "Molimo, ponovno učitajte stranicu",
-    "The update was unsuccessful. " : "Usklađivanje je bilo neuspješno.",
     "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspjelo. Upravo ste preusmjeravani na ownCloud.",
     "Searching other places" : "Pretraživanje drugih lokacija",
     "Personal" : "Osobno",
@@ -150,13 +152,6 @@ OC.L10N.register(
     "Apps" : "Aplikacije",
     "Admin" : "Admin",
     "Help" : "Pomoć",
-    "Error loading tags" : "Pogrešno učitavanje oznaka",
-    "Tag already exists" : "Oznaka već postoji",
-    "Error deleting tag(s)" : "Pogrešno brisanje oznake (oznaka)",
-    "Error tagging" : "Pogrešno označavanje",
-    "Error untagging" : "Pogrešno uklanjanje oznaka",
-    "Error favoriting" : "Pogrešno dodavanje u favorite",
-    "Error unfavoriting" : "Pogrešno uklanjanje iz favorita",
     "Access forbidden" : "Pristup zabranjen",
     "File not found" : "Datoteka nije pronađena",
     "The specified document has not been found on the server." : "Traženi dokument nije pronađen na poslužitelju.",
@@ -177,7 +172,6 @@ OC.L10N.register(
     "Line: %s" : "Red: %s",
     "Trace" : "Prati",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vašem podatkovnom direktoriju i datotekama vjerojatno se može pristupiti s interneta jer .htaccess datoteka ne radi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Za informaciju kako ispravno konfigurirati vaš poslužitelj, molimo vidite <a href=\"%s\" target=\"_blank\">dokumentaciju</a>.",
     "Create an <strong>admin account</strong>" : "Kreirajte <strong>admin račun</strong>",
     "Username" : "Korisničko ime",
     "Storage & database" : "Pohrana & baza podataka",
@@ -213,8 +207,6 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prije nego li nastavite, molimo osigurajte da su baza podataka, mapa konfiguracije i mapaza podatke sigurnosno kopirani.",
     "Start update" : "Započnite ažuriranje",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Da biste izbjegli vremensko prekoračenje s većim instalacijama, možete pokrenutisljedeću naredbu iz svoga instalacijskog direktorija:",
-    "This page will refresh itself when the %s instance is available again." : "Stranica će se sama osvježiti kada %s bude ponovo dostupno.",
-    "Error loading file picker template: {error}" : "Pogrešno učitavanje predloška za pronalazača datoteke: {error}",
-    "Password can not be changed. Please contact your administrator." : "Lozinku nije moguće promijeniti. Molimo kontaktirajte svog administratora."
+    "This page will refresh itself when the %s instance is available again." : "Stranica će se sama osvježiti kada %s bude ponovo dostupno."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
