@@ -1,25 +1,53 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Nebolo možné odoslať email týmto používateľom: %s ",
-    "Turned on maintenance mode" : "Mód údržby je zapnutý",
-    "Turned off maintenance mode" : "Mód údržby je vypnutý",
-    "Maintenance mode is kept active" : "Režim údržby je stále aktívny",
-    "Updated database" : "Databáza je aktualizovaná",
-    "Checked database schema update" : "Skontrolovať aktualizáciu schémy databázy",
-    "Checked database schema update for apps" : "Aktualizácia schémy databázy aplikácií bola overená",
-    "Updated \"%s\" to %s" : "Aktualizované \"%s\" na %s",
-    "Repair warning: " : "Oznámenie opravy:",
-    "Repair error: " : "Chyba opravy:",
-    "Following incompatible apps have been disabled: %s" : "Nasledovné nekompatibilné aplikácie boli zakázané: %s",
+    "Please select a file." : "Prosím, vyberte súbor.",
+    "File is too big" : "Súbor je príliš veľký",
     "Invalid file provided" : "Zadaný neplatný súbor",
     "No image or file provided" : "Obrázok alebo súbor nebol zadaný",
     "Unknown filetype" : "Neznámy typ súboru",
     "Invalid image" : "Chybný obrázok",
+    "An error occurred. Please contact your admin." : "Vyskytla sa chyba.\nProsím, kontaktujte svojho správcu.\n\t",
     "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
     "No crop data provided" : "Dáta pre orezanie neboli zadané",
     "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
     "Crop is not square" : "Orezanie nie je štvorcové",
+    "Couldn't reset password because the token is invalid" : "Nemožno zmeniť heslo pre neplatnosť tokenu.",
+    "Couldn't reset password because the token is expired" : "Nepodarilo sa obnoviť heslo, pretože platnosť tokenu uplynula.",
+    "Couldn't send reset email. Please make sure your username is correct." : "Nemožno poslať email pre obnovu. Uistite sa, či vkladáte správne používateľské meno.",
+    "%s password reset" : "reset hesla %s",
+    "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
+    "Error loading tags" : "Chyba pri načítaní štítkov",
+    "Tag already exists" : "Štítok už existuje",
+    "Error deleting tag(s)" : "Chyba pri mazaní štítka(ov)",
+    "Error tagging" : "Chyba pri pridaní štítka",
+    "Error untagging" : "Chyba pri odobratí štítka",
+    "Error favoriting" : "Chyba pri pridaní do obľúbených",
+    "Error unfavoriting" : "Chyba pri odobratí z obľúbených",
+    "Couldn't send mail to following users: %s " : "Nebolo možné odoslať email týmto používateľom: %s ",
+    "Preparing update" : "Pripravuje sa aktualizácia",
+    "Repair warning: " : "Oznámenie opravy:",
+    "Repair error: " : "Chyba opravy:",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrola tabuľky %s",
+    "Turned on maintenance mode" : "Mód údržby je zapnutý",
+    "Turned off maintenance mode" : "Mód údržby je vypnutý",
+    "Maintenance mode is kept active" : "Režim údržby je stále aktívny",
+    "Updating database schema" : "Aktualizuje sa schéma databázy",
+    "Updated database" : "Databáza je aktualizovaná",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontroluje sa, či je možné aktualizovať schému databázy (to môže trvať dlhší čas v závislosti na veľkosti databázy)",
+    "Checked database schema update" : "Skontrolovať aktualizáciu schémy databázy",
+    "Checking updates of apps" : "Kontrolujú sa aktualizácie aplikácií",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontroluje sa, či je možné aktualizovať schému databázy pre %s (to môže trvať dlhší čas v závislosti na veľkosti databázy)",
+    "Checked database schema update for apps" : "Aktualizácia schémy databázy aplikácií bola overená",
+    "Updated \"%s\" to %s" : "Aktualizované \"%s\" na %s",
+    "Set log level to debug" : "Nastaviť úroveň záznamu na ladenie",
+    "Reset log level" : "Obnoviť úroveň záznamu",
+    "Starting code integrity check" : "Začína kontrola integrity kódu",
+    "Finished code integrity check" : "Kontrola integrity kódu ukončená",
+    "%s (3rdparty)" : "%s (od tretej strany)",
+    "%s (incompatible)" : "%s (nekompatibilná)",
+    "Following apps have been disabled: %s" : "Nasledovné aplikácie boli zakázané: %s",
+    "Already up to date" : "Už aktuálne",
     "Sunday" : "Nedeľa",
     "Monday" : "Pondelok",
     "Tuesday" : "Utorok",
@@ -65,10 +93,11 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Pri kontrole integrity kódu sa vyskytli chyby. Viac informácií…</a>",
     "Settings" : "Nastavenia",
     "Saving..." : "Ukladám...",
+    "Dismiss" : "Odmietnuť",
     "seconds ago" : "pred sekundami",
-    "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovu hesla bol odoslaný na váš email. Pokiaľ ho neobdržíte v primeranom čase, skontrolujte spam / priečinok nevyžiadanej pošty. <br> Ak tam nie je, kontaktujte svojho administrátora.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Súbory sú zašifrované. Ak ste nepovolili kľúč pre obnovenie, neexistuje žiadny spôsob, ako obnoviť vaše dáta po obnovení vášho hesla. <br /> Ak si nie ste istí čo urobiť, prosím skôr než budete pokračovať, obráťte sa na administrátora. <br /> Naozaj chcete pokračovať?",
     "I know what I'm doing" : "Viem, čo robím",
@@ -98,33 +127,34 @@ OC.L10N.register(
     "Strong password" : "Silné heslo",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Váš webový server nie je zatiaľ správne nastavený, aby umožnil synchronizáciu súborov, pretože rozhranie WebDAV sa zdá byť nefunkčné.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server nemá funkčné pripojenie k internetu. Niektoré moduly ako napr. externé úložisko, oznámenie o dostupných aktualizáciách alebo inštalácia aplikácií tretích strán nebudú fungovať. Vzdialený prístup k súborom a odosielanie oznamovacích emailov tiež nemusí fungovať. Ak chcete využívať všetky funkcie, odporúčame povoliť tomuto serveru pripojenie k internetu.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Váš priečinok s dátami aj vaše súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby priečinok s dátami nebol naďalej prístupný alebo presunúť priečinok s dátami mimo priestoru, ktorý webový server sprístupňuje.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "dev/urandom nie je prístupný na čítanie procesom PHP, čo z bezpečnostných dôvodov nie je vôbec odporúčané. Viac informácií nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurácia hlavičiek reverse proxy nie je správna alebo pristupujete k ownCloud z dôveryhodného proxy servera. Ak k ownCloud nepristupujete z dôveryhodného proxy servera, vzniká bezpečnostné riziko - IP adresa potenciálneho útočníka, ktorú vidí ownCloud, môže byť falošná. Viac informácií nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached je nakonfigurovaný ako distribuovaná vyrovnávacia pamäť, ale v PHP je nainštalovaný nesprávny modul - \"memcache\". \\OC\\Memcache\\Memcached podporuje len modul \"memcached\", \"memcache\" nie je podporovaný. Viac informácií nájdete na <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki stránke o oboch moduloch</a>.",
     "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Váš priečinok s dátami aj vaše súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby priečinok s dátami nebol naďalej prístupný alebo presunúť priečinok s dátami mimo priestoru, ktorý webový server sprístupňuje.",
     "Shared" : "Zdieľané",
     "Shared with {recipients}" : "Zdieľa s {recipients}",
     "Error" : "Chyba",
     "Error while sharing" : "Chyba počas zdieľania",
     "Error while unsharing" : "Chyba počas ukončenia zdieľania",
-    "Error while changing permissions" : "Chyba počas zmeny oprávnení",
     "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
     "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
     "Set expiration date" : "Nastaviť dátum expirácie",
     "Expiration" : "Koniec platnosti",
     "Expiration date" : "Dátum expirácie",
-    "Sending ..." : "Odosielam ...",
-    "Email sent" : "Email odoslaný",
+    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
     "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
     "Share link" : "Zdieľať linku",
     "Link" : "Odkaz",
     "Password protect" : "Chrániť heslom",
     "Password" : "Heslo",
-    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
     "Allow editing" : "Povoliť úpravy",
     "Email link to person" : "Odoslať odkaz emailom",
     "Send" : "Odoslať",
+    "Sending ..." : "Odosielam ...",
+    "Email sent" : "Email odoslaný",
     "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
     "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
-    "Shared in {item} with {user}" : "Zdieľané v {item} s {user}",
     "group" : "skupina",
     "remote" : "vzdialený",
     "notify by email" : "informovať emailom",
@@ -135,14 +165,23 @@ OC.L10N.register(
     "change" : "zmeniť",
     "delete" : "vymazať",
     "access control" : "prístupové práva",
-    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
+    "Could not unshare" : "Nepodarilo sa zrušiť sprístupnenie",
+    "Share details could not be loaded for this item." : "Nebolo možné načítať údaje o zdieľaní tejto položky.",
+    "{sharee} (at {server})" : "{sharee} (na {server})",
     "Share" : "Zdieľať",
-    "Share with users or groups …" : "Zdieľať s používateľmi alebo skupinami ...",
-    "Share with users, groups or remote users …" : "Zdieľať s používateľmi, skupinami alebo vzdialenými používateľmi ...",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Zdieľať s ľuďmi na iných serveroch ownClouds pomocou syntaxe používateľ@doména.com/owncloud",
+    "Share with users…" : "Sprístupniť používateľom...",
+    "Share with users, groups or remote users…" : "Sprístupniť používateľom, skupinám alebo vzdialeným používateľom...",
+    "Share with users or groups…" : "Sprístupniť používateľom alebo skupinám...",
+    "Share with users or remote users…" : "Sprístupniť používateľom alebo vzdialeným používateľom...",
+    "Error removing share" : "Chyba pri rušení sprístupnenia",
     "Warning" : "Varovanie",
+    "Error while sending notification" : "Chyba pri posielaní oznámenia",
+    "invisible" : "neviditeľný",
+    "Delete" : "Zmazať",
+    "Rename" : "Premenovať",
     "The object type is not specified." : "Nešpecifikovaný typ objektu.",
     "Enter new" : "Zadať nový",
-    "Delete" : "Zmazať",
     "Add" : "Pridať",
     "Edit tags" : "Upraviť štítky",
     "Error loading dialog template: {error}" : "Chyba pri načítaní šablóny dialógu: {error}",
@@ -152,33 +191,24 @@ OC.L10N.register(
     "sunny" : "slnečno",
     "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
     "Hello {name}" : "Vitaj {name}",
+    "new" : "nový",
     "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov"],
-    "{version} is available. Get more information on how to update." : "{version} je dostupná. Získajte viac informácií o postupe aktualizácie.",
-    "Updating {productName} to version {version}, this may take a while." : "Aktualizujem {productName} na verziu {version}, chvíľu to môže trvať.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
+    "Updating to {version}" : "Aktualizuje sa na {version}",
+    "An error occurred." : "Vyskytla sa chyba.",
     "Please reload the page." : "Obnovte prosím stránku.",
-    "The update was unsuccessful. " : "Aktualizácia bola neúspešná.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizácia neprebehla úspešne. Pre viac informácií <a href=\"{url}\">navštívte príspevok na našom fóre</a>, ktorý pokrýva tento problém.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Aktualizácia nebola úspešná. Problém nahláste <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud comunite</a>.",
+    "The update was successful. There were warnings." : "Aktualizácia bola úspešná. Vyskytli sa upozornenia.",
     "The update was successful. Redirecting you to ownCloud now." : "Aktualizácia bola úspešná. Presmerovávam vás na prihlasovaciu stránku.",
-    "Couldn't reset password because the token is invalid" : "Nemožno zmeniť heslo pre neplatnosť tokenu.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Nemožno poslať email pre obnovu. Uistite sa, či vkladáte správne používateľské meno.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Nemožno poslať email pre obnovu hesla, pretože pre tohoto používateľa nie je uvedená žiadna emailová adresa. Prosím, obráťte sa na administrátora.",
-    "%s password reset" : "reset hesla %s",
-    "Use the following link to reset your password: {link}" : "Použite nasledujúci odkaz pre obnovenie vášho hesla: {link}",
-    "New password" : "Nové heslo",
-    "New Password" : "Nové heslo",
-    "Reset password" : "Obnovenie hesla",
     "Searching other places" : "Prehľadanie ostatných umiestnení",
+    "No search results in other folders" : "Žiadne výsledky vyhľadávania v ostatných priečinkoch",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} výsledok vyhľadávania v ostatných priečinkoch","{count} výsledky vyhľadávania v ostatných priečinkoch","{count} výsledkov vyhľadávania v ostatných priečinkoch"],
     "Personal" : "Osobné",
     "Users" : "Používatelia",
     "Apps" : "Aplikácie",
     "Admin" : "Administrácia",
     "Help" : "Pomoc",
-    "Error loading tags" : "Chyba pri načítaní štítkov",
-    "Tag already exists" : "Štítok už existuje",
-    "Error deleting tag(s)" : "Chyba pri mazaní štítka(ov)",
-    "Error tagging" : "Chyba pri pridaní štítka",
-    "Error untagging" : "Chyba pri odobratí štítka",
-    "Error favoriting" : "Chyba pri pridaní do obľúbených",
-    "Error unfavoriting" : "Chyba pri odobratí z obľúbených",
     "Access forbidden" : "Prístup odmietnutý",
     "File not found" : "Súbor nenájdený",
     "The specified document has not been found on the server." : "Zadaný dokument nebol nájdený na serveri.",
@@ -201,7 +231,6 @@ OC.L10N.register(
     "Trace" : "Trasa",
     "Security warning" : "Bezpečnostné varovanie",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pre informácie, ako správne nastaviť váš server, sa pozrite do <a href=\"%s\" target=\"_blank\">dokumentácie</a>.",
     "Create an <strong>admin account</strong>" : "Vytvoriť <strong>administrátorský účet</strong>",
     "Username" : "Meno používateľa",
     "Storage & database" : "Úložislo & databáza",
@@ -223,31 +252,39 @@ OC.L10N.register(
     "Finishing …" : "Dokončujem...",
     "Need help?" : "Potrebujete pomoc?",
     "See the documentation" : "Pozri dokumentáciu",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Dobrý deň,<br><br>Používateľ %s zdieľa s vami súbor, alebo priečinok s názvom »%s«.<br><a href=\"%s\">Pre zobrazenie kliknite na túto linku!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Táto aplikácia vyžaduje JavaScript, aby správne fungovala. Prosím, {linkstart}zapnite si JavaScript{linkend} a obnovte stránku",
     "Log out" : "Odhlásiť",
     "Search" : "Hľadať",
     "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
     "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
-    "An internal error occured." : "Vyskytla sa vnútorná chyba.",
+    "An internal error occurred." : "Došlo k vnútornej chybe.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
     "Log in" : "Prihlásiť sa",
     "Wrong password. Reset it?" : "Chybné heslo. Chcete ho obnoviť?",
-    "remember" : "zapamätať",
+    "Wrong password." : "Nesprávne heslo.",
+    "Stay logged in" : "Zostať prihlásený",
     "Alternative Logins" : "Alternatívne prihlásenie",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Dobrý deň,<br><br>Používateľ %s zdieľa s vami súbor, alebo priečinok s názvom »%s«.<br><a href=\"%s\">Pre zobrazenie kliknite na túto linku!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Použite nasledujúci odkaz pre obnovenie vášho hesla: {link}",
+    "New password" : "Nové heslo",
+    "New Password" : "Nové heslo",
+    "Reset password" : "Obnovenie hesla",
     "This ownCloud instance is currently in single user mode." : "Táto inštancia ownCloudu je teraz v jednopoužívateľskom móde.",
     "This means only administrators can use the instance." : "Len správca systému môže používať túto inštanciu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
     "Thank you for your patience." : "Ďakujeme za Vašu trpezlivosť.",
     "You are accessing the server from an untrusted domain." : "Pristupujete na server v nedôveryhodnej doméne.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontaktujte správcu. Ak ste správcom tejto inštancie, nakonfigurujte správne nastavenie \"trusted_domain\" v config/config.php. Vzorová konfigurácia je uvedená v config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "V závislosti na konfigurácii, vám môže byť ako správcovi umožnené použitie tlačidla nižšie pre označenie tejto domény ako dôveryhodnej.",
     "Add \"%s\" as trusted domain" : "Pridať \"%s\" ako dôveryhodnú doménu",
+    "App update required" : "Je nutná aktualizácia aplikácie",
     "%s will be updated to version %s" : "%s bude zaktualizovaný na verziu %s.",
+    "These apps will be updated:" : "Tieto aplikácie budú aktualizované:",
+    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
     "The theme %s has been disabled." : "Téma %s bola zakázaná.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
     "Start update" : "Spustiť aktualizáciu",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
+    "Detailed logs" : "Podrobné záznamy",
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the %s instance is available again." : "Táto stránka sa obnoví sama hneď ako bude %s inštancia znovu dostupná."
 },
