@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es wurde festgestellt, dass die Beispielkonfiguration kopiert wurde. Dies kann Deine Installation zerstören und wird nicht unterstützt. Bitte lies die Dokumentation, bevor Du Änderungen an der config.php vornimmst.",
     "PHP %s or higher is required." : "PHP %s oder höher wird benötigt.",
     "PHP with a version lower than %s is required." : "PHP wird in einer früheren Version als %s benötigt.",
+    "%sbit or higher PHP required." : "%sbit oder höheres PHP wird benötigt.",
     "Following databases are supported: %s" : "Die folgenden Datenbanken werden unterstützt: %s",
     "The command line tool %s could not be found" : "Das Kommandozeilenwerkzeug %s konnte nicht gefunden werden",
     "The library %s is not available." : "Die Bibliothek %s ist nicht verfügbar.",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
     "ownCloud %s or higher is required." : "ownCloud %s oder höher wird benötigt.",
     "ownCloud %s or lower is required." : "ownCloud %s oder niedriger wird benötigt.",
-    "Help" : "Hilfe",
-    "Personal" : "Persönlich",
-    "Users" : "Benutzer",
-    "Admin" : "Administration",
-    "Recommended" : "Empfohlen",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Die App „%s“ kann nicht installiert werden, da sie mit dieser ownCloud-Version nicht kompatibel ist.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Die App „%s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %s",
-    "No app name specified" : "Es wurde kein App-Name angegeben",
     "Unknown filetype" : "Unbekannter Dateityp",
     "Invalid image" : "Ungültiges Bild",
     "today" : "Heute",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["Vor %n Stunde","Vor %n Stunden"],
     "_%n minute ago_::_%n minutes ago_" : ["Vor %n Minute","Vor %n Minuten"],
     "seconds ago" : "Gerade eben",
-    "web services under your control" : "Web-Dienste unter Deiner Kontrolle",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Das Modul mit der ID: %s existiert nicht. Bitte aktiviere es in Deinen App-Einstellungen oder kontaktiere Deinen Administrator.",
     "Empty filename is not allowed" : "Ein leerer Dateiname ist nicht erlaubt",
     "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
     "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
     "File name is too long" : "Dateiname ist zu lang",
-    "File is currently busy, please try again later" : "Die Datei ist zur Zeit in Benutzung, bitte versuche es später noch einmal",
-    "Can't read file" : "Datei kann nicht gelesen werden",
     "App directory already exists" : "Das Applikationsverzeichnis existiert bereits",
     "Can't create app folder. Please fix permissions. %s" : "Es kann kein Applikationsordner erstellt werden. Bitte passe die  Berechtigungen an. %s",
     "Archive does not contain a directory named %s" : "Das Archiv enthält kein Verzeichnis mit dem Namen %s",
@@ -56,14 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Archive vom Typ %s werden nicht unterstützt",
     "Failed to open archive when installing app" : "Das Archiv konnte bei der Installation der Applikation nicht geöffnet werden",
     "App does not provide an info.xml file" : "Die Applikation enthält keine info.xml Datei",
+    "App cannot be installed because appinfo file cannot be read." : "Die Anwendung kann nicht installiert werden, weil die Anwendungsinfodatei nicht gelesen werden kann.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Die Signatur konnte nicht überprüft werden. Bitte kontaktiere  die App-Entwickler und überprüfe deinen Admin-Bildschirm.",
     "App can't be installed because of not allowed code in the App" : "Die App kann nicht installiert werden, weil sie unerlaubten Code enthält",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Die App kann nicht installiert werden, weil sie mit dieser Version von ownCloud nicht kompatibel ist",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Die App kann nicht installiert werden, weil sie den <shipped>true</shipped>-Tag enthält, der bei Apps, die nicht zum Standardumfang von ownCloud gehören, nicht erlaubt ist",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Die App kann nicht installiert werden, weil die Version in info.xml/version nicht mit der Version aus dem App Store übereinstimmt",
-    "Application is not enabled" : "Die App ist nicht aktiviert",
-    "Authentication error" : "Authentifizierungsfehler",
-    "Token expired. Please reload page." : "Token abgelaufen. Bitte lade die Seite neu.",
-    "Unknown user" : "Unbekannter Benutzer",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Diese App kann nicht installiert werden, da die Version in info.xml nicht die gleiche Version wie die aus dem App Store ist.",
+    "%s enter the database username and name." : "%s bitte gib den Datenbank Benutzernamen und den Datenbank Namen ein.",
     "%s enter the database username." : "%s gib den Datenbank-Benutzernamen an.",
     "%s enter the database name." : "%s gib den Datenbanknamen an.",
     "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
@@ -87,7 +76,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %i nicht erlaubt.",
     "Sharing %s failed, because the file does not exist" : "Freigabe von %s fehlgeschlagen, da die Datei nicht existiert",
     "You are not allowed to share %s" : "Die Freigabe von %s ist Dir nicht erlaubt",
-    "Sharing %s failed, because the user %s is the item owner" : "Freigabe von %s fehlgeschlagen, da der Nutzer %s Besitzer des Objektes ist",
+    "Sharing %s failed, because you can not share with yourself" : "Freigabe von %s fehlgeschlagen, da du nichts mit dir selbst teilen kannst",
     "Sharing %s failed, because the user %s does not exist" : "Freigabe von %s fehlgeschlagen, da der Nutzer %s nicht existiert",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Freigabe von %s fehlgeschlagen, da der Nutzer %s kein Gruppenmitglied einer der Gruppen von %s ist",
     "Sharing %s failed, because this item is already shared with %s" : "Freigabe von %s fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
@@ -96,6 +85,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Freigabe von %s fehlgeschlagen, da %s kein Mitglied der Gruppe %s ist",
     "You need to provide a password to create a public link, only protected links are allowed" : "Es sind nur geschützte Links zulässig, daher müssen Sie ein Passwort angeben, um einen öffentlichen Link zu generieren",
     "Sharing %s failed, because sharing with links is not allowed" : "Freigabe von %s fehlgeschlagen, da das Teilen von Verknüpfungen nicht erlaubt ist",
+    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
     "Share type %s is not valid for %s" : "Freigabetyp %s ist nicht gültig für %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Das Setzen der Berechtigungen für %s ist fehlgeschlagen, da die Berechtigungen, die erteilten Berechtigungen %s überschreiten",
@@ -106,17 +96,41 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Freigabe-Backend %s muss in der OCP\\Share_Backend - Schnittstelle implementiert werden",
     "Sharing backend %s not found" : "Freigabe-Backend %s nicht gefunden",
     "Sharing backend for %s not found" : "Freigabe-Backend für %s nicht gefunden",
-    "Sharing %s failed, because the user %s is the original sharer" : "Freigabe von %s fehlgeschlagen, da der Nutzer %s der offizielle Freigeber ist",
+    "Sharing failed, because the user %s is the original sharer" : "Freigabe fehlgeschlagen, da der Nutzer %s der offizielle Freigeber ist",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Freigabe von %s fehlgeschlagen, da die Berechtigungen die erteilten Berechtigungen %s überschreiten",
     "Sharing %s failed, because resharing is not allowed" : "Freigabe von %s fehlgeschlagen, da das nochmalige Freigeben einer Freigabe nicht erlaubt ist",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Freigabe von %s fehlgeschlagen, da das Freigabe-Backend für %s nicht in dieser Quelle gefunden werden konnte",
     "Sharing %s failed, because the file could not be found in the file cache" : "Freigabe von %s fehlgeschlagen, da die Datei im Datei-Cache nicht gefunden werden konnte",
+    "Cannot increase permissions of %s" : "Kann die Berechtigungen von %s nicht erhöhen",
+    "Files can't be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
+    "Files can't be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
+    "Expiration date is in the past" : "Ablaufdatum ist in der Vergangenheit",
+    "Cannot set expiration date more than %s days in the future" : "Das Ablaufdatum kann nicht mehr als %s Tage in die Zukunft liegen",
     "Could not find category \"%s\"" : "Die Kategorie „%s“ konnte nicht gefunden werden",
     "Apps" : "Apps",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-“",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-'“",
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
+    "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
     "A valid password must be provided" : "Es muss ein gültiges Passwort angegeben werden",
     "The username is already being used" : "Dieser Benutzername existiert bereits",
+    "Login canceled by app" : "Anmeldung durch die App abgebrochen",
+    "User disabled" : "Nutzer deaktiviert",
+    "Help" : "Hilfe",
+    "Personal" : "Persönlich",
+    "Users" : "Benutzer",
+    "Admin" : "Administration",
+    "Recommended" : "Empfohlen",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Die Anwendung \"%s\" kann nicht installiert werden, weil die Anwendungsinfodatei nicht gelesen werden kann.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Die App „%s“ kann nicht installiert werden, da sie mit dieser ownCloud-Version nicht kompatibel ist.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Die App „%s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %s",
+    "No app name specified" : "Es wurde kein App-Name angegeben",
+    "web services under your control" : "Web-Dienste unter Deiner Kontrolle",
+    "File is currently busy, please try again later" : "Die Datei ist zur Zeit in Benutzung, bitte versuche es später noch einmal",
+    "Can't read file" : "Datei kann nicht gelesen werden",
+    "Application is not enabled" : "Die App ist nicht aktiviert",
+    "Authentication error" : "Authentifizierungsfehler",
+    "Token expired. Please reload page." : "Token abgelaufen. Bitte lade die Seite neu.",
+    "Unknown user" : "Unbekannter Benutzer",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Keine Datenbanktreiber (SQLite, MySQL oder PostgreSQL) installiert.",
     "Microsoft Windows Platform is not supported" : "Microsoft Windows-Plattform wird nicht unterstützt",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Der Betrieb von ownCloud Server auf der Microsoft Windows-Plattform wird nicht unterstützt. Falls Du keine Möglichkeit zur Migration des Servers an sich hast, wird die Benutzung eines Linux-Servers innerhalb einer virtuellen Maschine empfohlen. Linux-Pakete wie auch leicht in Betrieb zu nehmende Abbilder virtueller Maschinen findest Du auf <a href=\"%s\">%s</a>. Einige Tipps zur Migration bestehender Installationen auf Linux und ein Migrationsskript findest Du in <a href=\"%s\">unserer Dokumentation</a>.",
@@ -124,7 +138,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Das Schreiben in das „apps“-Verzeichnis ist nicht möglich",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dies kann normalerweise behoben werden, %sindem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird%s oder der App Store in der Konfigurationsdatei deaktiviert wird.",
     "Cannot create \"data\" directory (%s)" : "Das Erstellen des „data“-Verzeichnisses ist nicht möglich (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dies kann normalerweise repariert werden, indem dem Webserver <a href=\"%s\" target=\"_blank\" Schreibzugriff auf das Wurzelverzeichnis gegeben wird</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dies kann normalerweise repariert werden, indem dem Webserver <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> Schreibzugriff auf das Wurzelverzeichnis gegeben wird</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Berechtigungen können normalerweise repariert werden, indem dem Webserver %s Schreibzugriff auf das Wurzelverzeichnis %s gegeben wird.",
     "Setting locale to %s failed" : "Das Setzen der Umgebungslokale auf %s fehlgeschlagen",
     "Please install one of these locales on your system and restart your webserver." : "Bitte installiere eine dieser Sprachen auf Deinem System und starte den Webserver neu.",
@@ -134,20 +148,25 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Durch das Anpassen dieser Einstellung in der php.ini wird ownCloud wieder laufen",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload ist nicht auf den erwarteten Wert „0“, sondern stattdessen  auf „%s“ gesetzt",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bitte setze zum Beheben dieses Problems <code>mbstring.func_overload</code> in Deiner php.ini auf <code>0</code>.",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 wird benötigt. Zur Zeit ist %s installiert.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Um diesen Fehler zu beheben, aktualisiere bitte die libxml2 Version und starte deinen Browser neu.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
     "Please ask your server administrator to restart the web server." : "Bitte kontaktiere Deinen Server-Administrator und bitte um den Neustart des Webservers.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
     "Please upgrade your database version" : "Bitte aktualisiere Deine Datenbankversion",
-    "Error occurred while checking PostgreSQL version" : "Es ist ein Fehler beim Prüfen der PostgreSQL-Version aufgetreten",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Stelle bitte sicher, dass Du PostgreSQL >= 9 verwendest oder prüfe die Logs für weitere Informationen über den Fehler",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändere die Berechtigungen auf 0770 sodass das Verzeichnis nicht von anderen Nutzer angezeigt werden kann.",
     "Data directory (%s) is readable by other users" : "Daten-Verzeichnis (%s) ist von anderen Nutzern lesbar",
     "Data directory (%s) must be an absolute path" : "Das Datenverzeichnis (%s) muss ein absoluter Pfad sein",
     "Check the value of \"datadirectory\" in your configuration" : "Überprüfe bitte die Angabe unter „datadirectory“ in Deiner Konfiguration",
     "Data directory (%s) is invalid" : "Daten-Verzeichnis (%s) ist ungültig",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Bitte stelle sicher, dass das Datenverzeichnis auf seiner ersten Ebene eine Datei namens „.ocdata“ enthält.",
-    "Could not obtain lock type %d on \"%s\"." : "Sperrtyp %d auf „%s“ konnte nicht ermittelt werden."
+    "Could not obtain lock type %d on \"%s\"." : "Sperrtyp %d auf „%s“ konnte nicht ermittelt werden.",
+    "Storage unauthorized. %s" : "Speichern nicht erlaubt. %s",
+    "Storage incomplete configuration. %s" : "Unvollständige Konfiguration des Storage. %s",
+    "Storage connection error. %s" : "Verbindungsfehler zum Storage. %s",
+    "Storage not available" : "Speicher nicht verfügbar",
+    "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Storage. %s"
 },
 "nplurals=2; plural=(n != 1);");
