@@ -1,11 +1,6 @@
 OC.L10N.register(
     "lib",
     {
-    "Help" : "ជំនួយ",
-    "Personal" : "ផ្ទាល់​ខ្លួន",
-    "Users" : "អ្នកប្រើ",
-    "Admin" : "អ្នក​គ្រប់​គ្រង",
-    "No app name specified" : "មិន​បាន​បញ្ជាក់​ឈ្មោះ​កម្មវិធី",
     "Unknown filetype" : "មិន​ស្គាល់​ប្រភេទ​ឯកសារ",
     "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
     "today" : "ថ្ងៃនេះ",
@@ -16,12 +11,8 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n ម៉ោង​មុន"],
     "_%n minute ago_::_%n minutes ago_" : ["%n នាទី​មុន"],
     "seconds ago" : "វិនាទី​មុន",
-    "web services under your control" : "សេវាកម្ម​វេប​ក្រោម​ការ​ការ​បញ្ជា​របស់​អ្នក",
     "App directory already exists" : "មាន​ទីតាំង​ផ្ទុក​កម្មវិធី​រួច​ហើយ",
     "Can't create app folder. Please fix permissions. %s" : "មិន​អាច​បង្កើត​ថត​កម្មវិធី។ សូម​កែ​សម្រួល​សិទ្ធិ។ %s",
-    "Application is not enabled" : "មិន​បាន​បើក​កម្មវិធី",
-    "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
-    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់",
     "%s enter the database username." : "%s វាយ​បញ្ចូល​ឈ្មោះ​អ្នក​ប្រើ​មូលដ្ឋាន​ទិន្នន័យ។",
     "%s enter the database name." : "%s វាយ​បញ្ចូល​ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ។",
     "%s you may not use dots in the database name" : "%s អ្នក​អាច​មិន​ប្រើ​សញ្ញា​ចុច​នៅ​ក្នុង​ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ",
@@ -33,6 +24,15 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "រក​មិន​ឃើញ​ចំណាត់​ក្រុម \"%s\"",
     "Apps" : "កម្មវិធី",
     "A valid username must be provided" : "ត្រូវ​ផ្ដល់​ឈ្មោះ​អ្នក​ប្រើ​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
-    "A valid password must be provided" : "ត្រូវ​ផ្ដល់​ពាក្យ​សម្ងាត់​ឲ្យ​បាន​ត្រឹម​ត្រូវ"
+    "A valid password must be provided" : "ត្រូវ​ផ្ដល់​ពាក្យ​សម្ងាត់​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
+    "Help" : "ជំនួយ",
+    "Personal" : "ផ្ទាល់​ខ្លួន",
+    "Users" : "អ្នកប្រើ",
+    "Admin" : "អ្នក​គ្រប់​គ្រង",
+    "No app name specified" : "មិន​បាន​បញ្ជាក់​ឈ្មោះ​កម្មវិធី",
+    "web services under your control" : "សេវាកម្ម​វេប​ក្រោម​ការ​ការ​បញ្ជា​របស់​អ្នក",
+    "Application is not enabled" : "មិន​បាន​បើក​កម្មវិធី",
+    "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
+    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់"
 },
 "nplurals=1; plural=0;");
