@@ -1,10 +1,6 @@
 OC.L10N.register(
     "lib",
     {
-    "Help" : "Pomoć",
-    "Personal" : "Lično",
-    "Users" : "Korisnici",
-    "Admin" : "Adninistracija",
     "Unknown filetype" : "Nepoznat tip fajla",
     "Invalid image" : "Neispravna slika",
     "today" : "Danas",
@@ -12,9 +8,14 @@ OC.L10N.register(
     "last month" : "prošlog meseca",
     "last year" : "prošle godine",
     "seconds ago" : "Pre par sekundi",
-    "Authentication error" : "Greška pri autentifikaciji",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s neće raditi kako treba na ovoj platformi. Koristite na sopstvenu odgovornost.",
     "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate uzmite u obzir korišćenje GNU/Linux servera.",
-    "Apps" : "Programi"
+    "Apps" : "Programi",
+    "Help" : "Pomoć",
+    "Personal" : "Lično",
+    "Users" : "Korisnici",
+    "Admin" : "Adninistracija",
+    "Authentication error" : "Greška pri autentifikaciji",
+    "Storage not available" : "Skladište nije dostupno"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
