@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Avisos de seguidad y configuración",
-    "Sharing" : "Compartiendo",
-    "Server-side encryption" : "Cifrado en el servidor",
-    "External Storage" : "Almacenamiento externo",
-    "Cron" : "Cron",
-    "Email server" : "Servidor de correo electrónico",
-    "Log" : "Registro",
-    "Tips & tricks" : "Sugerencias y trucos",
-    "Updates" : "Actualizaciones",
-    "Couldn't remove app." : "No se pudo eliminar la aplicación.",
-    "Language changed" : "Idioma cambiado",
-    "Invalid request" : "Petición no válida",
-    "Authentication error" : "Error de autenticación",
-    "Admins can't remove themself from the admin group" : "Los administradores no se pueden eliminar a ellos mismos del grupo de administrador",
-    "Unable to add user to group %s" : "No se pudo añadir el usuario al grupo %s",
-    "Unable to remove user from group %s" : "No se pudo eliminar al usuario del grupo %s",
-    "Couldn't update app." : "No se pudo actualizar la aplicación.",
     "Wrong password" : "Contraseña incorrecta",
     "No user supplied" : "No se especificó un usuario",
+    "Authentication error" : "Error de autenticación",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Por favor facilite una contraseña de recuperación de administrador, sino podrían perderse todos los datos de usuario",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor compruebe la contraseña e inténtelo de nuevo.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend no admite cambios de contraseña, pero la clave de cifrado del usuario ha sido actualizada satisfactoriamente.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "Correo electrónico guardado",
     "Your full name has been changed." : "Se ha cambiado su nombre completo.",
     "Unable to change full name" : "No se puede cambiar el nombre completo",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avisos de seguridad y configuración",
+    "Sharing" : "Compartiendo",
+    "Server-side encryption" : "Cifrado en el servidor",
+    "External Storage" : "Almacenamiento externo",
+    "Cron" : "Cron",
+    "Email server" : "Servidor de correo electrónico",
+    "Log" : "Registro",
+    "Tips & tricks" : "Sugerencias y trucos",
+    "Updates" : "Actualizaciones",
+    "Couldn't remove app." : "No se pudo eliminar la aplicación.",
+    "Language changed" : "Idioma cambiado",
+    "Invalid request" : "Petición no válida",
+    "Admins can't remove themself from the admin group" : "Los administradores no se pueden eliminar a ellos mismos del grupo de administrador",
+    "Unable to add user to group %s" : "No se pudo añadir el usuario al grupo %s",
+    "Unable to remove user from group %s" : "No se pudo eliminar al usuario del grupo %s",
+    "Couldn't update app." : "No se pudo actualizar la aplicación.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "¿Está seguro de querer agregar \"{domain}\" como un dominio de confianza?",
     "Add trusted domain" : "Agregar dominio de confianza",
     "Migration in progress. Please wait until the migration is finished" : "Migración en curso. Por favor, espere hasta que la migración esté finalizada.",
@@ -63,8 +63,9 @@ OC.L10N.register(
     "Experimental" : "Experimental",
     "All" : "Todos",
     "No apps found for your version" : "No se han encontrado aplicaciones para su versión",
-    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplicaciones oficiales son desarrolladas por y dentro de la comunidad ownCloud. Estas ofrecen una funcionalidad central con ownCloud y están listas para su uso en producción. ",
-    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Las aplicaciones aprobadas son desarrolladas por desarrolladores de confianza y han pasado un control de seguridad superficial. Estas se mantienen activamente en un repositorio de código abierto y sus mantenedores las consideran estables para un uso normal.",
+    "The app will be downloaded from the app store" : "La app debe ser descargada desde una app store",
+    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Las aplicaciones oficiales se desarrollan por y dentro de la comunidad ownCloud. Estas ofrecen una funcionalidad crucial en ownCloud y están listas para su uso en producción. ",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Las aplicaciones aprobadas las desarrollan desarrolladores de confianza y han pasado un control de seguridad superficial. Estas se mantienen activamente en un repositorio de código abierto y sus encargados las consideran estables para un uso normal.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicación no está verificada por problemas de seguridad además de ser reciente o conocida por ser inestable. Instálela bajo su propio riesgo.",
     "Update to %s" : "Actualizar a %s",
     "_You have %n app update pending_::_You have %n app updates pending_" : ["Tiene %n actualización de app pendiente","Tiene %n actualizaciones de app pendientes"],
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Desactivar",
     "Enable" : "Activar",
     "Error while enabling app" : "Error mientras se activaba la aplicación",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Error: Esta App no puede habilitarse porque el servidor se volveria inestable.",
+    "Error: could not disable broken app" : "Error: No puedo deshabilitar la App dañada.",
+    "Error while disabling broken app" : "Error mientras deshabilitaba la App dañada",
     "Updating...." : "Actualizando...",
     "Error while updating app" : "Error mientras se actualizaba la aplicación",
     "Updated" : "Actualizado",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Desinstalar",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido activada pero necesita ser actualizada. Seras redirigido a la pagina de actualizariones en 5 segundos.",
     "App update" : "Actualización de aplicación",
-    "No apps found for \"{query}\"" : "No se han encontrado aplicaciones para \"{query}\"",
+    "No apps found for {query}" : "No se han encontrado apps para {query}",
+    "Disconnect" : "Desconectar",
+    "Error while loading browser sessions and device tokens" : "Error al cargar sesiones de navegador y \"tokens\" de dispositivos",
+    "Error while creating device token" : "Error al crear \"token\" de dispositivo",
+    "Error while deleting the token" : "Error al detectar el \"token\"",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ha ocurrido un error. Por favor, cargue un certificado PEM codificado en ASCII.",
     "Valid until {date}" : "Válido hasta {date}",
     "Delete" : "Eliminar",
@@ -108,7 +116,10 @@ OC.L10N.register(
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "A valid email must be provided" : "Se debe brindar una dirección de correo electrónico válida ",
     "__language_name__" : "Castellano",
+    "Unlimited" : "Ilimitado",
     "Personal info" : "Información personal",
+    "Sessions" : "Sesiones",
+    "App passwords" : "App de contraseñas",
     "Sync clients" : "Sincronizar clientes",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (Información, Avisos, Errores, debug y problemas fatales)",
     "Info, warnings, errors and fatal issues" : "Información, Avisos, Errores y problemas fatales",
@@ -122,32 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php parece que no está configurado correctamente para solicitar las variables de entorno del sistema. La prueba con getenv(\"PATH\") sólo retorna una respuesta vacía.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor, compruebe la <a target=\"_blank\" href=\"%s\">documentación de instalación ↗</a> para las notas de configuración de php y la configuración de php de su servidor, especialmente cuando use php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor revisa la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación de instalación ↗</a> para notas de configuración PHP y la configuración PHP de tu servidor, especialmente cuando se está usando php-fpm",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Se ha habilitado la configuración de sólo lectura. Esto evita tener que ajustar algunas configuraciones a través de la interfaz web. Además, el archivo debe hacerse modificable manualmente para cada actualización.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales no estén accesibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Su base de datos no se ejecuta con el nivel de aislamiento de transacción \"READ COMMITED\" . Ésto puede causar problemas cuando múltiples acciones se ejecutan en paralelo.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Su servidor está operando con Microsoft Windows. Le recomendamos GNU/Linux encarecidamente para disfrutar una experiencia óptima como usuario.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s una versión inferior %2$s está instalada, por razones de estabilidad y rendimiento, se recomienda actualizar a la versión %1$s más reciente .",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "No se ha encontrado el modulo PHP 'fileinfo'. Le recomendamos encarecidamente que habilite este módulo para obtener mejores resultados con la detección de tipos MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "El fichero de bloqueo de transaciones esta desactivado, esto pruede provocar problemas con \"race conditions\". Activa 'filelocking.enabled'  en config.php para evitar estos problemas. Visita la <a target=\"_blank\" href=\"%s\">documentación ↗</a> para mas información.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "El bloqueo de archivos transaccional está desactivado, esto podría conducir a problemas con 'race conditions'. Activa 'filelocking.enabled' en 'config.php' para solucionar esos problemas. Mira la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación ↗</a> para más información.",
     "System locale can not be set to a one which supports UTF-8." : "No se puede escoger una configuración regional que soporte UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de los archivos.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Es muy recomendable instalar los paquetes necesarios para poder soportar una de las siguientes configuraciones regionales: %s. ",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si su instalación no está ubicada en la raíz del dominio y usa el cron del sistema, puede haber problemas al generarse los URL. Para evitarlos, configure la opción \"overwrite.cli.url\" en su archivo config.php para que use la ruta de la raíz del sitio web de su instalación (sugerencia: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "No fue posible ejecutar cronjob vía CLI. Han aparecido los siguientes errores técnicos:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor revise las <a target=\"_blank\" href=\"%s\">guías de instalación ↗</a>, y compruebe los errores o avisos en el <a ref=\"#log-section\">registro</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, compruebe de nuevo las <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guías de instalación ↗</a>, y comprueba por cualquier error o advertencia en el  <a href=\"#log-section\">Registro</a>",
     "All checks passed." : "Ha pasado todos los controles",
-    "Open documentation" : "Documentación abierta",
+    "Open documentation" : "Abrir Documentación",
     "Allow apps to use the Share API" : "Permitir a las aplicaciones utilizar la API de Compartición",
     "Allow users to share via link" : "Permite a los usuarios compartir por medio de enlaces",
-    "Enforce password protection" : "Forzar la protección por contraseña.",
     "Allow public uploads" : "Permitir subidas públicas",
-    "Allow users to send mail notification for shared files" : "Permitir a los usuarios enviar mensajes de notificación para ficheros compartidos",
+    "Enforce password protection" : "Forzar la protección por contraseña.",
     "Set default expiration date" : "Establecer fecha de caducidad predeterminada",
+    "Allow users to send mail notification for shared files" : "Permitir a los usuarios enviar mensajes de notificación para ficheros compartidos",
     "Expire after " : "Caduca luego de",
     "days" : "días",
     "Enforce expiration date" : "Imponer fecha de caducidad",
     "Allow resharing" : "Permitir recompartición",
+    "Allow sharing with groups" : "Permitir compartir con grupos",
     "Restrict users to only share with users in their groups" : "Restringe a los usuarios a compartir solo con otros usuarios en sus grupos",
     "Allow users to send mail notification for shared files to other users" : "Permitir a los usuarios enviar notificaciones por correo electrónico de los archivos compartidos a otros usuarios",
     "Exclude groups from sharing" : "Excluye grupos de compartir",
@@ -194,7 +207,7 @@ OC.L10N.register(
     "What to log" : "Que registrar",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Se utiliza SQLite como base de datos. Para instalaciones mas grandes se recomiende cambiar a otro sistema de base de datos. ",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLite está desaconsejado especialmente cuando se usa el cliente de escritorio para sincronizar los ficheros.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Para migrar a otra base de datos use la herramienta de línea de comandos: 'occ db:convert-type', o consulte la <a target=\"_blank\" href=\"%s\">documentación ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Para migrar a otra base de datos usa la herramienta de línea de comandos 'occ db:convert-type' o mira la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación ↗</a>.",
     "How to do backups" : "Cómo hacer copias de seguridad",
     "Advanced monitoring" : "Monitorización avanzada",
     "Performance tuning" : "Ajuste de rendimiento",
@@ -206,10 +219,12 @@ OC.L10N.register(
     "Experimental applications ahead" : "Aplicaciones experimentales más adelante",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Las aplicaciones experimentales no están verificadas por problemas de seguridad, recientes o conocidas por ser inestables y/o bajo un fuerte desarrollo. Instalándolas pueden causar pérdida de datos o violación de seguridades.",
     "by %s" : "por %s",
-    "%s-licensed" : "%s-licenciado",
+    "%s-licensed" : "Licencia %s",
     "Documentation:" : "Documentación:",
     "User documentation" : "Documentación de usuario",
     "Admin documentation" : "Documentación de administrador",
+    "Visit website" : "Visite nuestro sitio web",
+    "Report a bug" : "Notificar un error",
     "Show description …" : "Mostrar descripción…",
     "Hide description …" : "Ocultar descripción…",
     "This app has an update available." : "Está app tiene una actualización pendiente.",
@@ -256,19 +271,29 @@ OC.L10N.register(
     "Change password" : "Cambiar contraseña",
     "Language" : "Idioma",
     "Help translate" : "Ayúdanos a traducir",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estos son los clientes en web, en escritorio y en móvil actualmente conectados en su OwnCloud.",
+    "Browser" : "Navegador",
+    "Most recent activity" : "Actividad más reciente",
+    "You've linked these apps." : "Has enlazado estas apps.",
+    "Name" : "Nombre",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Una contraseña de app es un código que proporciona permisos a una app o dispositivo para acceder a tu cuenta %s.",
+    "App name" : "nombre de la app",
+    "Create new app password" : "Crear una nueva contraseña en la app",
+    "Use the credentials below to configure your app or device." : "Use la contraseña generada para configurar su app o dispositivo.",
+    "Username" : "Nombre de usuario",
+    "Done" : "Hecho",
     "Get the apps to sync your files" : "Obtener las aplicaciones para sincronizar sus archivos",
     "Desktop client" : "Cliente de escritorio",
     "Android app" : "Aplicación de Android",
     "iOS app" : "La aplicación de iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si quiere colaborar con el proyecto\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">participe en el desarrollo</a>\n\t\to\n\t\t¡<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">difúndalo</a>!",
     "Show First Run Wizard again" : "Mostrar nuevamente el Asistente de ejecución inicial",
-    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desarrollado por la {communityopen}comunidad Owncloud{linkclose}, el {githubopen}código fuente{linkclose} está licenciado bajo {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desarrollado por la {communityopen}comunidad ownCloud{linkclose}, el {githubopen}código fuente{linkclose} está bajo la licencia {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Mostrar la ubicación del almacenamiento",
     "Show last log in" : "Mostrar el último inicio de sesión",
     "Show user backend" : "Mostrar motor de usuario",
     "Send email to new user" : "Enviar correo al usuario nuevo",
     "Show email address" : "Mostrar dirección de correo electrónico",
-    "Username" : "Nombre de usuario",
     "E-Mail" : "Correo electrónico",
     "Create" : "Crear",
     "Admin Recovery Password" : "Recuperación de la contraseña de administración",
@@ -279,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Administradores",
     "Default Quota" : "Cuota predeterminada",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indique la cúota de almacenamiento (ej: \"512 MB\" o \"12 GB\")",
-    "Unlimited" : "Ilimitado",
     "Other" : "Otro",
     "Full Name" : "Nombre completo",
     "Group Admin for" : "Grupo administrador para",
