@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Avisos de seguridade e configuración",
-    "Sharing" : "Compartindo",
-    "Server-side encryption" : "Cifrado na parte do servidor",
-    "External Storage" : "Almacenamento externo",
-    "Cron" : "Cron",
-    "Email server" : "Servidor de correo",
-    "Log" : "Rexistro",
-    "Tips & tricks" : "Trucos e consellos",
-    "Updates" : "Actualizacións",
-    "Couldn't remove app." : "Non foi posíbel retirar a aplicación.",
-    "Language changed" : "O idioma cambiou",
-    "Invalid request" : "Petición incorrecta",
-    "Authentication error" : "Produciuse un erro de autenticación",
-    "Admins can't remove themself from the admin group" : "Os administradores non poden eliminarse a si mesmos do grupo admin",
-    "Unable to add user to group %s" : "Non é posíbel engadir o usuario ao grupo %s",
-    "Unable to remove user from group %s" : "Non é posíbel eliminar o usuario do grupo %s",
-    "Couldn't update app." : "Non foi posíbel actualizar a aplicación.",
     "Wrong password" : "Contrasinal incorrecto",
     "No user supplied" : "Non subministrado polo usuario",
+    "Authentication error" : "Produciuse un erro de autenticación",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Forneza un contrasinal de recuperación do administrador de recuperación, senón perderanse todos os datos do usuario",
     "Wrong admin recovery password. Please check the password and try again." : "Contrasinal de recuperación do administrador incorrecto. Comprobe o contrasinal e ténteo de novo.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "A infraestrutura non admite o cambio de contrasinal, mais a chave de cifrado do usuario foi actualizada correctamente.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "Correo gardado",
     "Your full name has been changed." : "O seu nome completo foi cambiado",
     "Unable to change full name" : "Non é posíbel cambiar o nome completo",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avisos de seguridade e configuración",
+    "Sharing" : "Compartindo",
+    "Server-side encryption" : "Cifrado na parte do servidor",
+    "External Storage" : "Almacenamento externo",
+    "Cron" : "Cron",
+    "Email server" : "Servidor de correo",
+    "Log" : "Rexistro",
+    "Tips & tricks" : "Trucos e consellos",
+    "Updates" : "Actualizacións",
+    "Couldn't remove app." : "Non foi posíbel retirar a aplicación.",
+    "Language changed" : "O idioma cambiou",
+    "Invalid request" : "Petición incorrecta",
+    "Admins can't remove themself from the admin group" : "Os administradores non poden eliminarse a si mesmos do grupo admin",
+    "Unable to add user to group %s" : "Non é posíbel engadir o usuario ao grupo %s",
+    "Unable to remove user from group %s" : "Non é posíbel eliminar o usuario do grupo %s",
+    "Couldn't update app." : "Non foi posíbel actualizar a aplicación.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Confirma que quere engadir «{domain}» como dominio de confianza?",
     "Add trusted domain" : "Engadir dominio de confianza",
     "Migration in progress. Please wait until the migration is finished" : "A migración está en proceso. Agarde a que remate.",
@@ -102,6 +102,7 @@ OC.L10N.register(
     "A valid password must be provided" : "Debe fornecer un contrasinal",
     "A valid email must be provided" : "Ten que fornecer un correo funcional",
     "__language_name__" : "Galego",
+    "Unlimited" : "Sen límites",
     "Personal info" : "Información persoal",
     "Sync clients" : "Clientes de sincronización",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (incidencias críticas, erros, avisos, información, depuración)",
@@ -126,14 +127,13 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Recomendámoslle que instale no sistema os paquetes necesarios para admitir unha das seguintes configuracións rexionais: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a instalación no está feita na raíz do dominio e usa o sistema cron, pode haber incidencias coa xeración de URL. Para evitar estes problemas, axuste a opción «overwrite.cli.url» no seu ficheiro config.php á ruta webroot da instalación (suxestión: «%s»)",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Non foi posíbel executar a tarefa de cron programada desde a liña de ordes. Atopáronse os seguintes erros técnicos:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Volva comprobar as <a target=\"_blank\" href=\"%s\">guías de instalación ↗</a>, e comprobe que non existen erros ou avisos no <a href=\"#log-section\">rexistro</a>.>.",
     "Open documentation" : "Abrir a documentación",
     "Allow apps to use the Share API" : "Permitir que as aplicacións empreguen o API para compartir",
     "Allow users to share via link" : "Permitir que os usuarios compartan a través de ligazóns",
-    "Enforce password protection" : "Forzar a protección por contrasinal",
     "Allow public uploads" : "Permitir os envíos públicos",
-    "Allow users to send mail notification for shared files" : "Permitirlle aos usuarios enviar notificacións por correo para os ficheiros compartidos",
+    "Enforce password protection" : "Forzar a protección por contrasinal",
     "Set default expiration date" : "Definir a data predeterminada de caducidade",
+    "Allow users to send mail notification for shared files" : "Permitirlle aos usuarios enviar notificacións por correo para os ficheiros compartidos",
     "Expire after " : "Caduca após",
     "days" : "días",
     "Enforce expiration date" : "Obrigar a data de caducidade",
@@ -176,7 +176,6 @@ OC.L10N.register(
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "O ficheiro de rexistro é maior de 100 MB. Pódelle levar un anaco descargalo!",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Empregase SQLite como base de datos. Para instalacións grandes recomendámoslle que cambie a unha infraestrutura de base de datos diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Concretamente, se emprega o cliente de escritorio para sincronización, desaconsellámoslle o uso de SQLite",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Para migrar cara outra base de datos, empregue a ferramenta en liña de ordes: «occ db:convert-type», ou vexa a <a target=\"_blank\" href=\"%s\">documentación ↗</a>.",
     "How to do backups" : "Como facer copias de seguridade",
     "Advanced monitoring" : "Supervisión avanzada",
     "Performance tuning" : "Afinación do rendemento",
@@ -226,6 +225,9 @@ OC.L10N.register(
     "Change password" : "Cambiar o contrasinal",
     "Language" : "Idioma",
     "Help translate" : "Axude na tradución",
+    "Name" : "Nome",
+    "Username" : "Nome de usuario",
+    "Done" : "Feito",
     "Get the apps to sync your files" : "Obteña as aplicacións para sincronizar os seus ficheiros",
     "Desktop client" : "Cliente de escritorio",
     "Android app" : "Aplicación Android",
@@ -238,7 +240,6 @@ OC.L10N.register(
     "Show user backend" : "Amosar a infraestrutura do usuario",
     "Send email to new user" : "Enviar correo ao novo usuario",
     "Show email address" : "Amosar o enderezo de correo",
-    "Username" : "Nome de usuario",
     "E-Mail" : "Correo-e",
     "Create" : "Crear",
     "Admin Recovery Password" : "Contrasinal de recuperación do administrador",
@@ -249,7 +250,6 @@ OC.L10N.register(
     "Admins" : "Administradores",
     "Default Quota" : "Cota por omisión",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Introduza a cota de almacenamento (p.ex. «512 MB» ou «12 GB»)",
-    "Unlimited" : "Sen límites",
     "Other" : "Outro",
     "Full Name" : "Nome completo",
     "Group Admin for" : "Grupo de Admin para",
