@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Bezpečnosť a nastavenia upozornení",
-    "Sharing" : "Zdieľanie",
-    "Server-side encryption" : "Šifrovanie na serveri",
-    "External Storage" : "Externé úložisko",
-    "Cron" : "Cron",
-    "Email server" : "Email server",
-    "Log" : "Záznam",
-    "Tips & tricks" : "Tipy a triky",
-    "Updates" : "Aktualizácie",
-    "Couldn't remove app." : "Nemožno odstrániť aplikáciu.",
-    "Language changed" : "Jazyk zmenený",
-    "Invalid request" : "Neplatná požiadavka",
-    "Authentication error" : "Chyba autentifikácie",
-    "Admins can't remove themself from the admin group" : "Administrátori nesmú odstrániť sami seba zo skupiny admin",
-    "Unable to add user to group %s" : "Nie je možné pridať používateľa do skupiny %s",
-    "Unable to remove user from group %s" : "Nie je možné odstrániť používateľa zo skupiny %s",
-    "Couldn't update app." : "Nemožno aktualizovať aplikáciu.",
     "Wrong password" : "Nesprávne heslo",
     "No user supplied" : "Nebol uvedený používateľ",
+    "Authentication error" : "Chyba autentifikácie",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Zadajte administrátorské heslo pre obnovu, inak budú všetky dáta stratené",
     "Wrong admin recovery password. Please check the password and try again." : "Chybné administrátorské heslo pre obnovu. Skontrolujte správnosť hesla a skúste to znovu.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend nepodporuje zmenu hesla, ale šifrovací kľúč používateľa bol úspešne zmenený.",
@@ -51,6 +33,24 @@ OC.L10N.register(
     "Email saved" : "Email uložený",
     "Your full name has been changed." : "Vaše meno a priezvisko bolo zmenené.",
     "Unable to change full name" : "Nemožno zmeniť meno a priezvisko",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Bezpečnosť a nastavenia upozornení",
+    "Sharing" : "Zdieľanie",
+    "Server-side encryption" : "Šifrovanie na serveri",
+    "External Storage" : "Externé úložisko",
+    "Cron" : "Cron",
+    "Email server" : "Email server",
+    "Log" : "Záznam",
+    "Tips & tricks" : "Tipy a triky",
+    "Updates" : "Aktualizácie",
+    "Couldn't remove app." : "Nemožno odstrániť aplikáciu.",
+    "Language changed" : "Jazyk zmenený",
+    "Invalid request" : "Neplatná požiadavka",
+    "Admins can't remove themself from the admin group" : "Administrátori nesmú odstrániť sami seba zo skupiny admin",
+    "Unable to add user to group %s" : "Nie je možné pridať používateľa do skupiny %s",
+    "Unable to remove user from group %s" : "Nie je možné odstrániť používateľa zo skupiny %s",
+    "Couldn't update app." : "Nemožno aktualizovať aplikáciu.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ste si istí, že chcete pridať \"{domain}\" medzi dôveryhodné domény?",
     "Add trusted domain" : "Pridať dôveryhodnú doménu",
     "Migration in progress. Please wait until the migration is finished" : "Prebieha migrácia. Počkajte prosím, kým sa skončí",
@@ -95,6 +95,7 @@ OC.L10N.register(
     "A valid password must be provided" : "Musíte zadať platné heslo",
     "A valid email must be provided" : "Musíte zadať platnú emailovú adresu",
     "__language_name__" : "Slovensky",
+    "Unlimited" : "Nelimitované",
     "Personal info" : "Osobné informácie",
     "Sync clients" : "Klienti synchronizácie",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Všetko (fatálne problémy, chyby, upozornenia, info, debug)",
@@ -120,10 +121,10 @@ OC.L10N.register(
     "Open documentation" : "Otvoriť dokumentáciu",
     "Allow apps to use the Share API" : "Povoliť aplikáciám používať API na zdieľanie",
     "Allow users to share via link" : "Povoliť používateľom zdieľanie pomocou odkazov",
-    "Enforce password protection" : "Vynútiť ochranu heslom",
     "Allow public uploads" : "Povoliť verejné nahrávanie súborov",
-    "Allow users to send mail notification for shared files" : "Povoliť používateľom zasielať emailom oznámenie o zdieľaní súborov",
+    "Enforce password protection" : "Vynútiť ochranu heslom",
     "Set default expiration date" : "Nastaviť predvolený dátum expirácie",
+    "Allow users to send mail notification for shared files" : "Povoliť používateľom zasielať emailom oznámenie o zdieľaní súborov",
     "Expire after " : "Platnosť do",
     "days" : "dni",
     "Enforce expiration date" : "Vynútiť dátum expirácie",
@@ -212,6 +213,9 @@ OC.L10N.register(
     "Change password" : "Zmeniť heslo",
     "Language" : "Jazyk",
     "Help translate" : "Pomôcť s prekladom",
+    "Name" : "Názov",
+    "Username" : "Používateľské meno",
+    "Done" : "Hotovo",
     "Get the apps to sync your files" : "Získať aplikácie na synchronizáciu vašich súborov",
     "Desktop client" : "Desktopový klient",
     "Android app" : "Android aplikácia",
@@ -224,7 +228,6 @@ OC.L10N.register(
     "Show user backend" : "Zobraziť backend používateľa",
     "Send email to new user" : "Odoslať email novému používateľovi",
     "Show email address" : "Zobraziť emailovú adresu",
-    "Username" : "Používateľské meno",
     "E-Mail" : "email",
     "Create" : "Vytvoriť",
     "Admin Recovery Password" : "Obnovenie hesla administrátora",
@@ -235,7 +238,6 @@ OC.L10N.register(
     "Admins" : "Administrátori",
     "Default Quota" : "Predvolená kvóta",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Prosím zadajte kvótu úložného priestoru (napr.: \"512 MB​​\" alebo \"12 GB\")",
-    "Unlimited" : "Nelimitované",
     "Other" : "Iné",
     "Full Name" : "Meno a priezvisko",
     "Group Admin for" : "Administrátor skupiny",
